# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/route/v4alpha/route_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.core.v4alpha import proxy_protocol_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_proxy__protocol__pb2
from envoy.type.matcher.v4alpha import regex_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from envoy.type.metadata.v3 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2
from envoy.type.tracing.v3 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/route/v4alpha/route_components.proto',
  package='envoy.config.route.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.config.route.v4alphaB\024RouteComponentsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1envoy/config/route/v4alpha/route_components.proto\x12\x1a\x65nvoy.config.route.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a.envoy/config/core/v4alpha/proxy_protocol.proto\x1a&envoy/type/matcher/v4alpha/regex.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a%envoy/type/metadata/v3/metadata.proto\x1a&envoy/type/tracing/v3/custom_tag.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbc\n\n\x0bVirtualHost\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x07\x64omains\x18\x02 \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\x08\x01\"\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x31\n\x06routes\x18\x03 \x03(\x0b\x32!.envoy.config.route.v4alpha.Route\x12Y\n\x0brequire_tls\x18\x04 \x01(\x0e\x32:.envoy.config.route.v4alpha.VirtualHost.TlsRequirementTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x44\n\x10virtual_clusters\x18\x05 \x03(\x0b\x32*.envoy.config.route.v4alpha.VirtualCluster\x12:\n\x0brate_limits\x18\x06 \x03(\x0b\x32%.envoy.config.route.v4alpha.RateLimit\x12W\n\x16request_headers_to_add\x18\x07 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x35\n\x19request_headers_to_remove\x18\r \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\"\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12X\n\x17response_headers_to_add\x18\n \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x36\n\x1aresponse_headers_to_remove\x18\x0b \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\"\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x34\n\x04\x63ors\x18\x08 \x01(\x0b\x32&.envoy.config.route.v4alpha.CorsPolicy\x12\x62\n\x17typed_per_filter_config\x18\x0f \x03(\x0b\x32\x41.envoy.config.route.v4alpha.VirtualHost.TypedPerFilterConfigEntry\x12%\n\x1dinclude_request_attempt_count\x18\x0e \x01(\x08\x12)\n!include_attempt_count_in_response\x18\x13 \x01(\x08\x12=\n\x0cretry_policy\x18\x10 \x01(\x0b\x32\'.envoy.config.route.v4alpha.RetryPolicy\x12\x37\n\x19retry_policy_typed_config\x18\x14 \x01(\x0b\x32\x14.google.protobuf.Any\x12=\n\x0chedge_policy\x18\x11 \x01(\x0b\x32\'.envoy.config.route.v4alpha.HedgePolicy\x12\x44\n\x1eper_request_buffer_limit_bytes\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\":\n\x12TlsRequirementType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rEXTERNAL_ONLY\x10\x01\x12\x07\n\x03\x41LL\x10\x02:(\x9a\xc5\x88\x1e#\n!envoy.config.route.v3.VirtualHostJ\x04\x08\t\x10\nJ\x04\x08\x0c\x10\rR\x11per_filter_config\"_\n\x0c\x46ilterAction\x12$\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any:)\x9a\xc5\x88\x1e$\n\"envoy.config.route.v3.FilterAction\"\xf2\x08\n\x05Route\x12\x0c\n\x04name\x18\x0e \x01(\t\x12?\n\x05match\x18\x01 \x01(\x0b\x32&.envoy.config.route.v4alpha.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x38\n\x05route\x18\x02 \x01(\x0b\x32\'.envoy.config.route.v4alpha.RouteActionH\x00\x12>\n\x08redirect\x18\x03 \x01(\x0b\x32*.envoy.config.route.v4alpha.RedirectActionH\x00\x12K\n\x0f\x64irect_response\x18\x07 \x01(\x0b\x32\x30.envoy.config.route.v4alpha.DirectResponseActionH\x00\x12\x41\n\rfilter_action\x18\x11 \x01(\x0b\x32(.envoy.config.route.v4alpha.FilterActionH\x00\x12\x35\n\x08metadata\x18\x04 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12\x38\n\tdecorator\x18\x05 \x01(\x0b\x32%.envoy.config.route.v4alpha.Decorator\x12\\\n\x17typed_per_filter_config\x18\r \x03(\x0b\x32;.envoy.config.route.v4alpha.Route.TypedPerFilterConfigEntry\x12W\n\x16request_headers_to_add\x18\t \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x35\n\x19request_headers_to_remove\x18\x0c \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\"\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12X\n\x17response_headers_to_add\x18\n \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x36\n\x1aresponse_headers_to_remove\x18\x0b \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\"\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x34\n\x07tracing\x18\x0f \x01(\x0b\x32#.envoy.config.route.v4alpha.Tracing\x12\x44\n\x1eper_request_buffer_limit_bytes\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.config.route.v3.RouteB\r\n\x06\x61\x63tion\x12\x03\xf8\x42\x01J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tR\x11per_filter_config\"\xc5\x07\n\x0fWeightedCluster\x12U\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x39.envoy.config.route.v4alpha.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12;\n\x0ctotal_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x12runtime_key_prefix\x18\x02 \x01(\t\x1a\xd3\x05\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x0emetadata_match\x18\x03 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12W\n\x16request_headers_to_add\x18\x04 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\t \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12X\n\x17response_headers_to_add\x18\x05 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x34\n\x1aresponse_headers_to_remove\x18\x06 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12t\n\x17typed_per_filter_config\x18\n \x03(\x0b\x32S.envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01::\x9a\xc5\x88\x1e\x35\n3envoy.config.route.v3.WeightedCluster.ClusterWeightJ\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tR\x11per_filter_config:,\x9a\xc5\x88\x1e\'\n%envoy.config.route.v3.WeightedCluster\"\xa4\x08\n\nRouteMatch\x12\x10\n\x06prefix\x18\x01 \x01(\tH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12H\n\nsafe_regex\x18\n \x01(\x0b\x32(.envoy.type.matcher.v4alpha.RegexMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12P\n\x0f\x63onnect_matcher\x18\x0c \x01(\x0b\x32\x35.envoy.config.route.v4alpha.RouteMatch.ConnectMatcherH\x00\x12\x32\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x10runtime_fraction\x18\t \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercent\x12:\n\x07headers\x18\x06 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x12K\n\x10query_parameters\x18\x07 \x03(\x0b\x32\x31.envoy.config.route.v4alpha.QueryParameterMatcher\x12J\n\x04grpc\x18\x08 \x01(\x0b\x32<.envoy.config.route.v4alpha.RouteMatch.GrpcRouteMatchOptions\x12R\n\x0btls_context\x18\x0b \x01(\x0b\x32=.envoy.config.route.v4alpha.RouteMatch.TlsContextMatchOptions\x1aV\n\x15GrpcRouteMatchOptions:=\x9a\xc5\x88\x1e\x38\n6envoy.config.route.v3.RouteMatch.GrpcRouteMatchOptions\x1a\xb6\x01\n\x16TlsContextMatchOptions\x12-\n\tpresented\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tvalidated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:>\x9a\xc5\x88\x1e\x39\n7envoy.config.route.v3.RouteMatch.TlsContextMatchOptions\x1aH\n\x0e\x43onnectMatcher:6\x9a\xc5\x88\x1e\x31\n/envoy.config.route.v3.RouteMatch.ConnectMatcher:\'\x9a\xc5\x88\x1e\"\n envoy.config.route.v3.RouteMatchB\x15\n\x0epath_specifier\x12\x03\xf8\x42\x01J\x04\x08\x05\x10\x06J\x04\x08\x03\x10\x04R\x05regex\"\xff\x03\n\nCorsPolicy\x12L\n\x19\x61llow_origin_string_match\x18\x0b \x03(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcher\x12\x15\n\rallow_methods\x18\x02 \x01(\t\x12\x15\n\rallow_headers\x18\x03 \x01(\t\x12\x16\n\x0e\x65xpose_headers\x18\x04 \x01(\t\x12\x0f\n\x07max_age\x18\x05 \x01(\t\x12\x35\n\x11\x61llow_credentials\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercentH\x00\x12K\n\x0eshadow_enabled\x18\n \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercent:\'\x9a\xc5\x88\x1e\"\n envoy.config.route.v3.CorsPolicyB\x13\n\x11\x65nabled_specifierJ\x04\x08\x01\x10\x02J\x04\x08\x08\x10\tJ\x04\x08\x07\x10\x08R\x0c\x61llow_originR\x12\x61llow_origin_regexR\x07\x65nabled\"\x8e \n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\'\n\x0e\x63luster_header\x18\x02 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00H\x00\x12H\n\x11weighted_clusters\x18\x03 \x01(\x0b\x32+.envoy.config.route.v4alpha.WeightedClusterH\x00\x12v\n\x1f\x63luster_not_found_response_code\x18\x14 \x01(\x0e\x32\x43.envoy.config.route.v4alpha.RouteAction.ClusterNotFoundResponseCodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12;\n\x0emetadata_match\x18\x04 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12#\n\x0eprefix_rewrite\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12J\n\rregex_rewrite\x18  \x01(\x0b\x32\x33.envoy.type.matcher.v4alpha.RegexMatchAndSubstitute\x12+\n\x14host_rewrite_literal\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x01\x12\x37\n\x11\x61uto_host_rewrite\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x12*\n\x13host_rewrite_header\x18\x1d \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00H\x01\x12V\n\x17host_rewrite_path_regex\x18# \x01(\x0b\x32\x33.envoy.type.matcher.v4alpha.RegexMatchAndSubstituteH\x01\x12*\n\x07timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cidle_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x0cretry_policy\x18\t \x01(\x0b\x32\'.envoy.config.route.v4alpha.RetryPolicy\x12\x37\n\x19retry_policy_typed_config\x18! \x01(\x0b\x32\x14.google.protobuf.Any\x12\\\n\x17request_mirror_policies\x18\x1e \x03(\x0b\x32;.envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy\x12\x46\n\x08priority\x18\x0b \x01(\x0e\x32*.envoy.config.core.v4alpha.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12:\n\x0brate_limits\x18\r \x03(\x0b\x32%.envoy.config.route.v4alpha.RateLimit\x12G\n\x0bhash_policy\x18\x0f \x03(\x0b\x32\x32.envoy.config.route.v4alpha.RouteAction.HashPolicy\x12\x34\n\x04\x63ors\x18\x11 \x01(\x0b\x32&.envoy.config.route.v4alpha.CorsPolicy\x12N\n\x0fupgrade_configs\x18\x19 \x03(\x0b\x32\x35.envoy.config.route.v4alpha.RouteAction.UpgradeConfig\x12T\n\x18internal_redirect_policy\x18\" \x01(\x0b\x32\x32.envoy.config.route.v4alpha.InternalRedirectPolicy\x12=\n\x0chedge_policy\x18\x1b \x01(\x0b\x32\'.envoy.config.route.v4alpha.HedgePolicy\x12V\n\x13max_stream_duration\x18$ \x01(\x0b\x32\x39.envoy.config.route.v4alpha.RouteAction.MaxStreamDuration\x1a\x82\x02\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12M\n\x10runtime_fraction\x18\x03 \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercent\x12\x31\n\rtrace_sampled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:<\x9a\xc5\x88\x1e\x37\n5envoy.config.route.v3.RouteAction.RequestMirrorPolicyJ\x04\x08\x02\x10\x03R\x0bruntime_key\x1a\xb9\t\n\nHashPolicy\x12K\n\x06header\x18\x01 \x01(\x0b\x32\x39.envoy.config.route.v4alpha.RouteAction.HashPolicy.HeaderH\x00\x12K\n\x06\x63ookie\x18\x02 \x01(\x0b\x32\x39.envoy.config.route.v4alpha.RouteAction.HashPolicy.CookieH\x00\x12h\n\x15\x63onnection_properties\x18\x03 \x01(\x0b\x32G.envoy.config.route.v4alpha.RouteAction.HashPolicy.ConnectionPropertiesH\x00\x12\\\n\x0fquery_parameter\x18\x05 \x01(\x0b\x32\x41.envoy.config.route.v4alpha.RouteAction.HashPolicy.QueryParameterH\x00\x12V\n\x0c\x66ilter_state\x18\x06 \x01(\x0b\x32>.envoy.config.route.v4alpha.RouteAction.HashPolicy.FilterStateH\x00\x12\x10\n\x08terminal\x18\x04 \x01(\x08\x1a\xb4\x01\n\x06Header\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12J\n\rregex_rewrite\x18\x02 \x01(\x0b\x32\x33.envoy.type.matcher.v4alpha.RegexMatchAndSubstitute::\x9a\xc5\x88\x1e\x35\n3envoy.config.route.v3.RouteAction.HashPolicy.Header\x1a\x91\x01\n\x06\x43ookie\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x03ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04path\x18\x03 \x01(\t::\x9a\xc5\x88\x1e\x35\n3envoy.config.route.v3.RouteAction.HashPolicy.Cookie\x1as\n\x14\x43onnectionProperties\x12\x11\n\tsource_ip\x18\x01 \x01(\x08:H\x9a\xc5\x88\x1e\x43\nAenvoy.config.route.v3.RouteAction.HashPolicy.ConnectionProperties\x1ak\n\x0eQueryParameter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:B\x9a\xc5\x88\x1e=\n;envoy.config.route.v3.RouteAction.HashPolicy.QueryParameter\x1a\x64\n\x0b\x46ilterState\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.config.route.v3.RouteAction.HashPolicy.FilterState:3\x9a\xc5\x88\x1e.\n,envoy.config.route.v3.RouteAction.HashPolicyB\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x1a\xb1\x03\n\rUpgradeConfig\x12#\n\x0cupgrade_type\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00\x12+\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12[\n\x0e\x63onnect_config\x18\x03 \x01(\x0b\x32\x43.envoy.config.route.v4alpha.RouteAction.UpgradeConfig.ConnectConfig\x1a\xb8\x01\n\rConnectConfig\x12M\n\x15proxy_protocol_config\x18\x01 \x01(\x0b\x32..envoy.config.core.v4alpha.ProxyProtocolConfig\x12\x12\n\nallow_post\x18\x02 \x01(\x08:D\x9a\xc5\x88\x1e?\n=envoy.config.route.v3.RouteAction.UpgradeConfig.ConnectConfig:6\x9a\xc5\x88\x1e\x31\n/envoy.config.route.v3.RouteAction.UpgradeConfig\x1a\x82\x02\n\x11MaxStreamDuration\x12\x36\n\x13max_stream_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17grpc_timeout_header_max\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1agrpc_timeout_header_offset\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration::\x9a\xc5\x88\x1e\x35\n3envoy.config.route.v3.RouteAction.MaxStreamDuration\"E\n\x1b\x43lusterNotFoundResponseCode\x12\x17\n\x13SERVICE_UNAVAILABLE\x10\x00\x12\r\n\tNOT_FOUND\x10\x01:(\x9a\xc5\x88\x1e#\n!envoy.config.route.v3.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\x42\x18\n\x16host_rewrite_specifierJ\x04\x08\x0c\x10\rJ\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x10\x10\x11J\x04\x08\x16\x10\x17J\x04\x08\x15\x10\x16J\x04\x08\n\x10\x0bJ\x04\x08\x0e\x10\x0fJ\x04\x08\x17\x10\x18J\x04\x08\x1c\x10\x1dJ\x04\x08\x1a\x10\x1bJ\x04\x08\x1f\x10 R\x15request_mirror_policyR\x16include_vh_rate_limitsR\x10max_grpc_timeoutR\x13grpc_timeout_offsetR\x18internal_redirect_actionR\x16max_internal_redirects\"\xec\r\n\x0bRetryPolicy\x12\x10\n\x08retry_on\x18\x01 \x01(\t\x12\x31\n\x0bmax_retries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12M\n\x0eretry_priority\x18\x04 \x01(\x0b\x32\x35.envoy.config.route.v4alpha.RetryPolicy.RetryPriority\x12X\n\x14retry_host_predicate\x18\x05 \x03(\x0b\x32:.envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate\x12)\n!host_selection_retry_max_attempts\x18\x06 \x01(\x03\x12\x1e\n\x16retriable_status_codes\x18\x07 \x03(\r\x12L\n\x0eretry_back_off\x18\x08 \x01(\x0b\x32\x34.envoy.config.route.v4alpha.RetryPolicy.RetryBackOff\x12\x64\n\x1brate_limited_retry_back_off\x18\x0b \x01(\x0b\x32?.envoy.config.route.v4alpha.RetryPolicy.RateLimitedRetryBackOff\x12\x44\n\x11retriable_headers\x18\t \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x12L\n\x19retriable_request_headers\x18\n \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x1a\xa9\x01\n\rRetryPriority\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.config.route.v3.RetryPolicy.RetryPriorityB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1a\xb3\x01\n\x12RetryHostPredicate\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:;\x9a\xc5\x88\x1e\x36\n4envoy.config.route.v3.RetryPolicy.RetryHostPredicateB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1a\xbe\x01\n\x0cRetryBackOff\x12<\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.config.route.v3.RetryPolicy.RetryBackOff\x1a\xb5\x01\n\x0bResetHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12S\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x39.envoy.config.route.v4alpha.RetryPolicy.ResetHeaderFormatB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:4\x9a\xc5\x88\x1e/\n-envoy.config.route.v3.RetryPolicy.ResetHeader\x1a\xec\x01\n\x17RateLimitedRetryBackOff\x12T\n\rreset_headers\x18\x01 \x03(\x0b\x32\x33.envoy.config.route.v4alpha.RetryPolicy.ResetHeaderB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:@\x9a\xc5\x88\x1e;\n9envoy.config.route.v3.RetryPolicy.RateLimitedRetryBackOff\"4\n\x11ResetHeaderFormat\x12\x0b\n\x07SECONDS\x10\x00\x12\x12\n\x0eUNIX_TIMESTAMP\x10\x01:(\x9a\xc5\x88\x1e#\n!envoy.config.route.v3.RetryPolicy\"\xdf\x01\n\x0bHedgePolicy\x12?\n\x10initial_requests\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x43\n\x19\x61\x64\x64itional_request_chance\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12 \n\x18hedge_on_per_try_timeout\x18\x03 \x01(\x08:(\x9a\xc5\x88\x1e#\n!envoy.config.route.v3.HedgePolicy\"\xee\x04\n\x0eRedirectAction\x12\x18\n\x0ehttps_redirect\x18\x04 \x01(\x08H\x00\x12\x19\n\x0fscheme_redirect\x18\x07 \x01(\tH\x00\x12\"\n\rhost_redirect\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x15\n\rport_redirect\x18\x08 \x01(\r\x12$\n\rpath_redirect\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x01\x12%\n\x0eprefix_rewrite\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x01\x12L\n\rregex_rewrite\x18\t \x01(\x0b\x32\x33.envoy.type.matcher.v4alpha.RegexMatchAndSubstituteH\x01\x12`\n\rresponse_code\x18\x03 \x01(\x0e\x32?.envoy.config.route.v4alpha.RedirectAction.RedirectResponseCodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"w\n\x14RedirectResponseCode\x12\x15\n\x11MOVED_PERMANENTLY\x10\x00\x12\t\n\x05\x46OUND\x10\x01\x12\r\n\tSEE_OTHER\x10\x02\x12\x16\n\x12TEMPORARY_REDIRECT\x10\x03\x12\x16\n\x12PERMANENT_REDIRECT\x10\x04:+\x9a\xc5\x88\x1e&\n$envoy.config.route.v3.RedirectActionB\x1a\n\x18scheme_rewrite_specifierB\x18\n\x16path_rewrite_specifier\"\x9a\x01\n\x14\x44irectResponseAction\x12\x1a\n\x06status\x18\x01 \x01(\rB\n\xfa\x42\x07*\x05\x10\xd8\x04(d\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSource:1\x9a\xc5\x88\x1e,\n*envoy.config.route.v3.DirectResponseAction\"~\n\tDecorator\x12\x1a\n\toperation\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12-\n\tpropagate\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.route.v3.Decorator\"\x98\x02\n\x07Tracing\x12\x39\n\x0f\x63lient_sampling\x18\x01 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\x39\n\x0frandom_sampling\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12:\n\x10overall_sampling\x18\x03 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\x35\n\x0b\x63ustom_tags\x18\x04 \x03(\x0b\x32 .envoy.type.tracing.v3.CustomTag:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.config.route.v3.Tracing\"\xad\x01\n\x0eVirtualCluster\x12:\n\x07headers\x18\x04 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:+\x9a\xc5\x88\x1e&\n$envoy.config.route.v3.VirtualClusterJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04R\x07patternR\x06method\"\x8a\x15\n\tRateLimit\x12\x34\n\x05stage\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\n\x12\x13\n\x0b\x64isable_key\x18\x02 \x01(\t\x12G\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32,.envoy.config.route.v4alpha.RateLimit.ActionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12=\n\x05limit\x18\x04 \x01(\x0b\x32..envoy.config.route.v4alpha.RateLimit.Override\x1a\xb2\x10\n\x06\x41\x63tion\x12T\n\x0esource_cluster\x18\x01 \x01(\x0b\x32:.envoy.config.route.v4alpha.RateLimit.Action.SourceClusterH\x00\x12^\n\x13\x64\x65stination_cluster\x18\x02 \x01(\x0b\x32?.envoy.config.route.v4alpha.RateLimit.Action.DestinationClusterH\x00\x12V\n\x0frequest_headers\x18\x03 \x01(\x0b\x32;.envoy.config.route.v4alpha.RateLimit.Action.RequestHeadersH\x00\x12T\n\x0eremote_address\x18\x04 \x01(\x0b\x32:.envoy.config.route.v4alpha.RateLimit.Action.RemoteAddressH\x00\x12N\n\x0bgeneric_key\x18\x05 \x01(\x0b\x32\x37.envoy.config.route.v4alpha.RateLimit.Action.GenericKeyH\x00\x12[\n\x12header_value_match\x18\x06 \x01(\x0b\x32=.envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatchH\x00\x12I\n\x08metadata\x18\x08 \x01(\x0b\x32\x35.envoy.config.route.v4alpha.RateLimit.Action.MetaDataH\x00\x12\x44\n\textension\x18\t \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00\x1aL\n\rSourceCluster:;\x9a\xc5\x88\x1e\x36\n4envoy.config.route.v3.RateLimit.Action.SourceCluster\x1aV\n\x12\x44\x65stinationCluster:@\x9a\xc5\x88\x1e;\n9envoy.config.route.v3.RateLimit.Action.DestinationCluster\x1a\xab\x01\n\x0eRequestHeaders\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0eskip_if_absent\x18\x03 \x01(\x08:<\x9a\xc5\x88\x1e\x37\n5envoy.config.route.v3.RateLimit.Action.RequestHeaders\x1aL\n\rRemoteAddress:;\x9a\xc5\x88\x1e\x36\n4envoy.config.route.v3.RateLimit.Action.RemoteAddress\x1a\x81\x01\n\nGenericKey\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0e\x64\x65scriptor_key\x18\x02 \x01(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.config.route.v3.RateLimit.Action.GenericKey\x1a\xed\x01\n\x10HeaderValueMatch\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x30\n\x0c\x65xpect_match\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x07headers\x18\x03 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:>\x9a\xc5\x88\x1e\x39\n7envoy.config.route.v3.RateLimit.Action.HeaderValueMatch\x1a\xcd\x01\n\x0f\x44ynamicMetaData\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x43\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v3.MetadataKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x15\n\rdefault_value\x18\x03 \x01(\t:=\x9a\xc5\x88\x1e\x38\n6envoy.config.route.v3.RateLimit.Action.DynamicMetaData\x1a\xbf\x02\n\x08MetaData\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x43\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v3.MetadataKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x15\n\rdefault_value\x18\x03 \x01(\t\x12V\n\x06source\x18\x04 \x01(\x0e\x32<.envoy.config.route.v4alpha.RateLimit.Action.MetaData.SourceB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"&\n\x06Source\x12\x0b\n\x07\x44YNAMIC\x10\x00\x12\x0f\n\x0bROUTE_ENTRY\x10\x01:6\x9a\xc5\x88\x1e\x31\n/envoy.config.route.v3.RateLimit.Action.MetaData:-\x9a\xc5\x88\x1e(\n&envoy.config.route.v3.RateLimit.ActionB\x17\n\x10\x61\x63tion_specifier\x12\x03\xf8\x42\x01J\x04\x08\x07\x10\x08R\x10\x64ynamic_metadata\x1a\xcc\x02\n\x08Override\x12Z\n\x10\x64ynamic_metadata\x18\x01 \x01(\x0b\x32>.envoy.config.route.v4alpha.RateLimit.Override.DynamicMetadataH\x00\x1a\x97\x01\n\x0f\x44ynamicMetadata\x12\x43\n\x0cmetadata_key\x18\x01 \x01(\x0b\x32#.envoy.type.metadata.v3.MetadataKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.config.route.v3.RateLimit.Override.DynamicMetadata:/\x9a\xc5\x88\x1e*\n(envoy.config.route.v3.RateLimit.OverrideB\x19\n\x12override_specifier\x12\x03\xf8\x42\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.route.v3.RateLimit\"\xb4\x03\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x15\n\x0b\x65xact_match\x18\x04 \x01(\tH\x00\x12\x44\n\x10safe_regex_match\x18\x0b \x01(\x0b\x32(.envoy.type.matcher.v4alpha.RegexMatcherH\x00\x12\x30\n\x0brange_match\x18\x06 \x01(\x0b\x32\x19.envoy.type.v3.Int64RangeH\x00\x12\x17\n\rpresent_match\x18\x07 \x01(\x08H\x00\x12\x1f\n\x0cprefix_match\x18\t \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x1f\n\x0csuffix_match\x18\n \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12!\n\x0e\x63ontains_match\x18\x0c \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x14\n\x0cinvert_match\x18\x08 \x01(\x08:*\x9a\xc5\x88\x1e%\n#envoy.config.route.v3.HeaderMatcherB\x18\n\x16header_match_specifierJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06R\x0bregex_match\"\x88\x02\n\x15QueryParameterMatcher\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01(\x80\x08\x12K\n\x0cstring_match\x18\x05 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x17\n\rpresent_match\x18\x06 \x01(\x08H\x00:2\x9a\xc5\x88\x1e-\n+envoy.config.route.v3.QueryParameterMatcherB!\n\x1fquery_parameter_match_specifierJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x05valueR\x05regex\"\xa0\x02\n\x16InternalRedirectPolicy\x12<\n\x16max_internal_redirects\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12)\n\x17redirect_response_codes\x18\x02 \x03(\rB\x08\xfa\x42\x05\x92\x01\x02\x10\x05\x12\x43\n\npredicates\x18\x03 \x03(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig\x12#\n\x1b\x61llow_cross_scheme_redirect\x18\x04 \x01(\x08:3\x9a\xc5\x88\x1e.\n,envoy.config.route.v3.InternalRedirectPolicy\"t\n\x0c\x46ilterConfig\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0bis_optional\x18\x02 \x01(\x08:)\x9a\xc5\x88\x1e$\n\"envoy.config.route.v3.FilterConfigBJ\n(io.envoyproxy.envoy.config.route.v4alphaB\x14RouteComponentsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_proxy__protocol__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_VIRTUALHOST_TLSREQUIREMENTTYPE = _descriptor.EnumDescriptor(
  name='TlsRequirementType',
  full_name='envoy.config.route.v4alpha.VirtualHost.TlsRequirementType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1855,
  serialized_end=1913,
)
_sym_db.RegisterEnumDescriptor(_VIRTUALHOST_TLSREQUIREMENTTYPE)

_ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE = _descriptor.EnumDescriptor(
  name='ClusterNotFoundResponseCode',
  full_name='envoy.config.route.v4alpha.RouteAction.ClusterNotFoundResponseCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVICE_UNAVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9511,
  serialized_end=9580,
)
_sym_db.RegisterEnumDescriptor(_ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE)

_RETRYPOLICY_RESETHEADERFORMAT = _descriptor.EnumDescriptor(
  name='ResetHeaderFormat',
  full_name='envoy.config.route.v4alpha.RetryPolicy.ResetHeaderFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIX_TIMESTAMP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11563,
  serialized_end=11615,
)
_sym_db.RegisterEnumDescriptor(_RETRYPOLICY_RESETHEADERFORMAT)

_REDIRECTACTION_REDIRECTRESPONSECODE = _descriptor.EnumDescriptor(
  name='RedirectResponseCode',
  full_name='envoy.config.route.v4alpha.RedirectAction.RedirectResponseCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MOVED_PERMANENTLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEE_OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY_REDIRECT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_REDIRECT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12290,
  serialized_end=12409,
)
_sym_db.RegisterEnumDescriptor(_REDIRECTACTION_REDIRECTRESPONSECODE)

_RATELIMIT_ACTION_METADATA_SOURCE = _descriptor.EnumDescriptor(
  name='Source',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData.Source',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTE_ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15388,
  serialized_end=15426,
)
_sym_db.RegisterEnumDescriptor(_RATELIMIT_ACTION_METADATA_SOURCE)


_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY = _descriptor.Descriptor(
  name='TypedPerFilterConfigEntry',
  full_name='envoy.config.route.v4alpha.VirtualHost.TypedPerFilterConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.route.v4alpha.VirtualHost.TypedPerFilterConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.route.v4alpha.VirtualHost.TypedPerFilterConfigEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1853,
)

_VIRTUALHOST = _descriptor.Descriptor(
  name='VirtualHost',
  full_name='envoy.config.route.v4alpha.VirtualHost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.VirtualHost.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domains', full_name='envoy.config.route.v4alpha.VirtualHost.domains', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\017\222\001\014\010\001\"\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.config.route.v4alpha.VirtualHost.routes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_tls', full_name='envoy.config.route.v4alpha.VirtualHost.require_tls', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_clusters', full_name='envoy.config.route.v4alpha.VirtualHost.virtual_clusters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limits', full_name='envoy.config.route.v4alpha.VirtualHost.rate_limits', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.route.v4alpha.VirtualHost.request_headers_to_add', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.route.v4alpha.VirtualHost.request_headers_to_remove', index=7,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\017\222\001\014\"\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.config.route.v4alpha.VirtualHost.response_headers_to_add', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_remove', full_name='envoy.config.route.v4alpha.VirtualHost.response_headers_to_remove', index=9,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\017\222\001\014\"\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cors', full_name='envoy.config.route.v4alpha.VirtualHost.cors', index=10,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_per_filter_config', full_name='envoy.config.route.v4alpha.VirtualHost.typed_per_filter_config', index=11,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_request_attempt_count', full_name='envoy.config.route.v4alpha.VirtualHost.include_request_attempt_count', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_attempt_count_in_response', full_name='envoy.config.route.v4alpha.VirtualHost.include_attempt_count_in_response', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_policy', full_name='envoy.config.route.v4alpha.VirtualHost.retry_policy', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_policy_typed_config', full_name='envoy.config.route.v4alpha.VirtualHost.retry_policy_typed_config', index=15,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hedge_policy', full_name='envoy.config.route.v4alpha.VirtualHost.hedge_policy', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_request_buffer_limit_bytes', full_name='envoy.config.route.v4alpha.VirtualHost.per_request_buffer_limit_bytes', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY, ],
  enum_types=[
    _VIRTUALHOST_TLSREQUIREMENTTYPE,
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.config.route.v3.VirtualHost',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=1986,
)


_FILTERACTION = _descriptor.Descriptor(
  name='FilterAction',
  full_name='envoy.config.route.v4alpha.FilterAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.config.route.v4alpha.FilterAction.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.route.v3.FilterAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1988,
  serialized_end=2083,
)


_ROUTE_TYPEDPERFILTERCONFIGENTRY = _descriptor.Descriptor(
  name='TypedPerFilterConfigEntry',
  full_name='envoy.config.route.v4alpha.Route.TypedPerFilterConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.route.v4alpha.Route.TypedPerFilterConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.route.v4alpha.Route.TypedPerFilterConfigEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1853,
)

_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.config.route.v4alpha.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.Route.name', index=0,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.config.route.v4alpha.Route.match', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='envoy.config.route.v4alpha.Route.route', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect', full_name='envoy.config.route.v4alpha.Route.redirect', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_response', full_name='envoy.config.route.v4alpha.Route.direct_response', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_action', full_name='envoy.config.route.v4alpha.Route.filter_action', index=5,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.route.v4alpha.Route.metadata', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decorator', full_name='envoy.config.route.v4alpha.Route.decorator', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_per_filter_config', full_name='envoy.config.route.v4alpha.Route.typed_per_filter_config', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.route.v4alpha.Route.request_headers_to_add', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.route.v4alpha.Route.request_headers_to_remove', index=10,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\017\222\001\014\"\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.config.route.v4alpha.Route.response_headers_to_add', index=11,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_remove', full_name='envoy.config.route.v4alpha.Route.response_headers_to_remove', index=12,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\017\222\001\014\"\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracing', full_name='envoy.config.route.v4alpha.Route.tracing', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_request_buffer_limit_bytes', full_name='envoy.config.route.v4alpha.Route.per_request_buffer_limit_bytes', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTE_TYPEDPERFILTERCONFIGENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\035\n\033envoy.config.route.v3.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='envoy.config.route.v4alpha.Route.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2086,
  serialized_end=3224,
)


_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY = _descriptor.Descriptor(
  name='TypedPerFilterConfigEntry',
  full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1853,
)

_WEIGHTEDCLUSTER_CLUSTERWEIGHT = _descriptor.Descriptor(
  name='ClusterWeight',
  full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.metadata_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.request_headers_to_add', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.request_headers_to_remove', index=4,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.response_headers_to_add', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_remove', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.response_headers_to_remove', index=6,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_per_filter_config', full_name='envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.typed_per_filter_config', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.route.v3.WeightedCluster.ClusterWeight',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3423,
  serialized_end=4146,
)

_WEIGHTEDCLUSTER = _descriptor.Descriptor(
  name='WeightedCluster',
  full_name='envoy.config.route.v4alpha.WeightedCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.config.route.v4alpha.WeightedCluster.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_weight', full_name='envoy.config.route.v4alpha.WeightedCluster.total_weight', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key_prefix', full_name='envoy.config.route.v4alpha.WeightedCluster.runtime_key_prefix', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEIGHTEDCLUSTER_CLUSTERWEIGHT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.config.route.v3.WeightedCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3227,
  serialized_end=4192,
)


_ROUTEMATCH_GRPCROUTEMATCHOPTIONS = _descriptor.Descriptor(
  name='GrpcRouteMatchOptions',
  full_name='envoy.config.route.v4alpha.RouteMatch.GrpcRouteMatchOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.config.route.v3.RouteMatch.GrpcRouteMatchOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4827,
  serialized_end=4913,
)

_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS = _descriptor.Descriptor(
  name='TlsContextMatchOptions',
  full_name='envoy.config.route.v4alpha.RouteMatch.TlsContextMatchOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='presented', full_name='envoy.config.route.v4alpha.RouteMatch.TlsContextMatchOptions.presented', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validated', full_name='envoy.config.route.v4alpha.RouteMatch.TlsContextMatchOptions.validated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0369\n7envoy.config.route.v3.RouteMatch.TlsContextMatchOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4916,
  serialized_end=5098,
)

_ROUTEMATCH_CONNECTMATCHER = _descriptor.Descriptor(
  name='ConnectMatcher',
  full_name='envoy.config.route.v4alpha.RouteMatch.ConnectMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.route.v3.RouteMatch.ConnectMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5100,
  serialized_end=5172,
)

_ROUTEMATCH = _descriptor.Descriptor(
  name='RouteMatch',
  full_name='envoy.config.route.v4alpha.RouteMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.config.route.v4alpha.RouteMatch.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.route.v4alpha.RouteMatch.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_regex', full_name='envoy.config.route.v4alpha.RouteMatch.safe_regex', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_matcher', full_name='envoy.config.route.v4alpha.RouteMatch.connect_matcher', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_sensitive', full_name='envoy.config.route.v4alpha.RouteMatch.case_sensitive', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_fraction', full_name='envoy.config.route.v4alpha.RouteMatch.runtime_fraction', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.route.v4alpha.RouteMatch.headers', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameters', full_name='envoy.config.route.v4alpha.RouteMatch.query_parameters', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='envoy.config.route.v4alpha.RouteMatch.grpc', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_context', full_name='envoy.config.route.v4alpha.RouteMatch.tls_context', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTEMATCH_GRPCROUTEMATCHOPTIONS, _ROUTEMATCH_TLSCONTEXTMATCHOPTIONS, _ROUTEMATCH_CONNECTMATCHER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.config.route.v3.RouteMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='path_specifier', full_name='envoy.config.route.v4alpha.RouteMatch.path_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=4195,
  serialized_end=5255,
)


_CORSPOLICY = _descriptor.Descriptor(
  name='CorsPolicy',
  full_name='envoy.config.route.v4alpha.CorsPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_origin_string_match', full_name='envoy.config.route.v4alpha.CorsPolicy.allow_origin_string_match', index=0,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_methods', full_name='envoy.config.route.v4alpha.CorsPolicy.allow_methods', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_headers', full_name='envoy.config.route.v4alpha.CorsPolicy.allow_headers', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_headers', full_name='envoy.config.route.v4alpha.CorsPolicy.expose_headers', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_age', full_name='envoy.config.route.v4alpha.CorsPolicy.max_age', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_credentials', full_name='envoy.config.route.v4alpha.CorsPolicy.allow_credentials', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.config.route.v4alpha.CorsPolicy.filter_enabled', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_enabled', full_name='envoy.config.route.v4alpha.CorsPolicy.shadow_enabled', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.config.route.v3.CorsPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='enabled_specifier', full_name='envoy.config.route.v4alpha.CorsPolicy.enabled_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5258,
  serialized_end=5769,
)


_ROUTEACTION_REQUESTMIRRORPOLICY = _descriptor.Descriptor(
  name='RequestMirrorPolicy',
  full_name='envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_fraction', full_name='envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy.runtime_fraction', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_sampled', full_name='envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy.trace_sampled', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.config.route.v3.RouteAction.RequestMirrorPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7342,
  serialized_end=7600,
)

_ROUTEACTION_HASHPOLICY_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Header.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex_rewrite', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Header.regex_rewrite', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.route.v3.RouteAction.HashPolicy.Header',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8078,
  serialized_end=8258,
)

_ROUTEACTION_HASHPOLICY_COOKIE = _descriptor.Descriptor(
  name='Cookie',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Cookie',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Cookie.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Cookie.ttl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.Cookie.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.route.v3.RouteAction.HashPolicy.Cookie',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8261,
  serialized_end=8406,
)

_ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES = _descriptor.Descriptor(
  name='ConnectionProperties',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.ConnectionProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_ip', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.ConnectionProperties.source_ip', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036C\nAenvoy.config.route.v3.RouteAction.HashPolicy.ConnectionProperties',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8408,
  serialized_end=8523,
)

_ROUTEACTION_HASHPOLICY_QUERYPARAMETER = _descriptor.Descriptor(
  name='QueryParameter',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.QueryParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.QueryParameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.route.v3.RouteAction.HashPolicy.QueryParameter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8525,
  serialized_end=8632,
)

_ROUTEACTION_HASHPOLICY_FILTERSTATE = _descriptor.Descriptor(
  name='FilterState',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.FilterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.FilterState.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.route.v3.RouteAction.HashPolicy.FilterState',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8634,
  serialized_end=8734,
)

_ROUTEACTION_HASHPOLICY = _descriptor.Descriptor(
  name='HashPolicy',
  full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.cookie', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_properties', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.connection_properties', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameter', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.query_parameter', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.filter_state', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminal', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.terminal', index=5,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTEACTION_HASHPOLICY_HEADER, _ROUTEACTION_HASHPOLICY_COOKIE, _ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES, _ROUTEACTION_HASHPOLICY_QUERYPARAMETER, _ROUTEACTION_HASHPOLICY_FILTERSTATE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.route.v3.RouteAction.HashPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy_specifier', full_name='envoy.config.route.v4alpha.RouteAction.HashPolicy.policy_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=7603,
  serialized_end=8812,
)

_ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG = _descriptor.Descriptor(
  name='ConnectConfig',
  full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.ConnectConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_protocol_config', full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.ConnectConfig.proxy_protocol_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_post', full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.ConnectConfig.allow_post', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.config.route.v3.RouteAction.UpgradeConfig.ConnectConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9008,
  serialized_end=9192,
)

_ROUTEACTION_UPGRADECONFIG = _descriptor.Descriptor(
  name='UpgradeConfig',
  full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_type', full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.upgrade_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_config', full_name='envoy.config.route.v4alpha.RouteAction.UpgradeConfig.connect_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.route.v3.RouteAction.UpgradeConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8815,
  serialized_end=9248,
)

_ROUTEACTION_MAXSTREAMDURATION = _descriptor.Descriptor(
  name='MaxStreamDuration',
  full_name='envoy.config.route.v4alpha.RouteAction.MaxStreamDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_stream_duration', full_name='envoy.config.route.v4alpha.RouteAction.MaxStreamDuration.max_stream_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_timeout_header_max', full_name='envoy.config.route.v4alpha.RouteAction.MaxStreamDuration.grpc_timeout_header_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_timeout_header_offset', full_name='envoy.config.route.v4alpha.RouteAction.MaxStreamDuration.grpc_timeout_header_offset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.route.v3.RouteAction.MaxStreamDuration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9251,
  serialized_end=9509,
)

_ROUTEACTION = _descriptor.Descriptor(
  name='RouteAction',
  full_name='envoy.config.route.v4alpha.RouteAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.route.v4alpha.RouteAction.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_header', full_name='envoy.config.route.v4alpha.RouteAction.cluster_header', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_clusters', full_name='envoy.config.route.v4alpha.RouteAction.weighted_clusters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_not_found_response_code', full_name='envoy.config.route.v4alpha.RouteAction.cluster_not_found_response_code', index=3,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.config.route.v4alpha.RouteAction.metadata_match', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_rewrite', full_name='envoy.config.route.v4alpha.RouteAction.prefix_rewrite', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex_rewrite', full_name='envoy.config.route.v4alpha.RouteAction.regex_rewrite', index=6,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_rewrite_literal', full_name='envoy.config.route.v4alpha.RouteAction.host_rewrite_literal', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_host_rewrite', full_name='envoy.config.route.v4alpha.RouteAction.auto_host_rewrite', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_rewrite_header', full_name='envoy.config.route.v4alpha.RouteAction.host_rewrite_header', index=9,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_rewrite_path_regex', full_name='envoy.config.route.v4alpha.RouteAction.host_rewrite_path_regex', index=10,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.route.v4alpha.RouteAction.timeout', index=11,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.route.v4alpha.RouteAction.idle_timeout', index=12,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_policy', full_name='envoy.config.route.v4alpha.RouteAction.retry_policy', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_policy_typed_config', full_name='envoy.config.route.v4alpha.RouteAction.retry_policy_typed_config', index=14,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_mirror_policies', full_name='envoy.config.route.v4alpha.RouteAction.request_mirror_policies', index=15,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.config.route.v4alpha.RouteAction.priority', index=16,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limits', full_name='envoy.config.route.v4alpha.RouteAction.rate_limits', index=17,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_policy', full_name='envoy.config.route.v4alpha.RouteAction.hash_policy', index=18,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cors', full_name='envoy.config.route.v4alpha.RouteAction.cors', index=19,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrade_configs', full_name='envoy.config.route.v4alpha.RouteAction.upgrade_configs', index=20,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_redirect_policy', full_name='envoy.config.route.v4alpha.RouteAction.internal_redirect_policy', index=21,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hedge_policy', full_name='envoy.config.route.v4alpha.RouteAction.hedge_policy', index=22,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stream_duration', full_name='envoy.config.route.v4alpha.RouteAction.max_stream_duration', index=23,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTEACTION_REQUESTMIRRORPOLICY, _ROUTEACTION_HASHPOLICY, _ROUTEACTION_UPGRADECONFIG, _ROUTEACTION_MAXSTREAMDURATION, ],
  enum_types=[
    _ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE,
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.config.route.v3.RouteAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_specifier', full_name='envoy.config.route.v4alpha.RouteAction.cluster_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
    _descriptor.OneofDescriptor(
      name='host_rewrite_specifier', full_name='envoy.config.route.v4alpha.RouteAction.host_rewrite_specifier',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5772,
  serialized_end=9882,
)


_RETRYPOLICY_RETRYPRIORITY = _descriptor.Descriptor(
  name='RetryPriority',
  full_name='envoy.config.route.v4alpha.RetryPolicy.RetryPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryPriority.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryPriority.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.route.v3.RetryPolicy.RetryPriority',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryPriority.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10594,
  serialized_end=10763,
)

_RETRYPOLICY_RETRYHOSTPREDICATE = _descriptor.Descriptor(
  name='RetryHostPredicate',
  full_name='envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.route.v3.RetryPolicy.RetryHostPredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10766,
  serialized_end=10945,
)

_RETRYPOLICY_RETRYBACKOFF = _descriptor.Descriptor(
  name='RetryBackOff',
  full_name='envoy.config.route.v4alpha.RetryPolicy.RetryBackOff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_interval', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryBackOff.base_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_interval', full_name='envoy.config.route.v4alpha.RetryPolicy.RetryBackOff.max_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.route.v3.RetryPolicy.RetryBackOff',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10948,
  serialized_end=11138,
)

_RETRYPOLICY_RESETHEADER = _descriptor.Descriptor(
  name='ResetHeader',
  full_name='envoy.config.route.v4alpha.RetryPolicy.ResetHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RetryPolicy.ResetHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='envoy.config.route.v4alpha.RetryPolicy.ResetHeader.format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.route.v3.RetryPolicy.ResetHeader',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11141,
  serialized_end=11322,
)

_RETRYPOLICY_RATELIMITEDRETRYBACKOFF = _descriptor.Descriptor(
  name='RateLimitedRetryBackOff',
  full_name='envoy.config.route.v4alpha.RetryPolicy.RateLimitedRetryBackOff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reset_headers', full_name='envoy.config.route.v4alpha.RetryPolicy.RateLimitedRetryBackOff.reset_headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_interval', full_name='envoy.config.route.v4alpha.RetryPolicy.RateLimitedRetryBackOff.max_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.config.route.v3.RetryPolicy.RateLimitedRetryBackOff',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11325,
  serialized_end=11561,
)

_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='envoy.config.route.v4alpha.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='retry_on', full_name='envoy.config.route.v4alpha.RetryPolicy.retry_on', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_retries', full_name='envoy.config.route.v4alpha.RetryPolicy.max_retries', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_try_timeout', full_name='envoy.config.route.v4alpha.RetryPolicy.per_try_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_priority', full_name='envoy.config.route.v4alpha.RetryPolicy.retry_priority', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_host_predicate', full_name='envoy.config.route.v4alpha.RetryPolicy.retry_host_predicate', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_selection_retry_max_attempts', full_name='envoy.config.route.v4alpha.RetryPolicy.host_selection_retry_max_attempts', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retriable_status_codes', full_name='envoy.config.route.v4alpha.RetryPolicy.retriable_status_codes', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_back_off', full_name='envoy.config.route.v4alpha.RetryPolicy.retry_back_off', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limited_retry_back_off', full_name='envoy.config.route.v4alpha.RetryPolicy.rate_limited_retry_back_off', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retriable_headers', full_name='envoy.config.route.v4alpha.RetryPolicy.retriable_headers', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retriable_request_headers', full_name='envoy.config.route.v4alpha.RetryPolicy.retriable_request_headers', index=10,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRYPOLICY_RETRYPRIORITY, _RETRYPOLICY_RETRYHOSTPREDICATE, _RETRYPOLICY_RETRYBACKOFF, _RETRYPOLICY_RESETHEADER, _RETRYPOLICY_RATELIMITEDRETRYBACKOFF, ],
  enum_types=[
    _RETRYPOLICY_RESETHEADERFORMAT,
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.config.route.v3.RetryPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9885,
  serialized_end=11657,
)


_HEDGEPOLICY = _descriptor.Descriptor(
  name='HedgePolicy',
  full_name='envoy.config.route.v4alpha.HedgePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initial_requests', full_name='envoy.config.route.v4alpha.HedgePolicy.initial_requests', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_request_chance', full_name='envoy.config.route.v4alpha.HedgePolicy.additional_request_chance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hedge_on_per_try_timeout', full_name='envoy.config.route.v4alpha.HedgePolicy.hedge_on_per_try_timeout', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.config.route.v3.HedgePolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11660,
  serialized_end=11883,
)


_REDIRECTACTION = _descriptor.Descriptor(
  name='RedirectAction',
  full_name='envoy.config.route.v4alpha.RedirectAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='https_redirect', full_name='envoy.config.route.v4alpha.RedirectAction.https_redirect', index=0,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme_redirect', full_name='envoy.config.route.v4alpha.RedirectAction.scheme_redirect', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_redirect', full_name='envoy.config.route.v4alpha.RedirectAction.host_redirect', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_redirect', full_name='envoy.config.route.v4alpha.RedirectAction.port_redirect', index=3,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_redirect', full_name='envoy.config.route.v4alpha.RedirectAction.path_redirect', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_rewrite', full_name='envoy.config.route.v4alpha.RedirectAction.prefix_rewrite', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex_rewrite', full_name='envoy.config.route.v4alpha.RedirectAction.regex_rewrite', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_code', full_name='envoy.config.route.v4alpha.RedirectAction.response_code', index=7,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_query', full_name='envoy.config.route.v4alpha.RedirectAction.strip_query', index=8,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDIRECTACTION_REDIRECTRESPONSECODE,
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.config.route.v3.RedirectAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scheme_rewrite_specifier', full_name='envoy.config.route.v4alpha.RedirectAction.scheme_rewrite_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='path_rewrite_specifier', full_name='envoy.config.route.v4alpha.RedirectAction.path_rewrite_specifier',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11886,
  serialized_end=12508,
)


_DIRECTRESPONSEACTION = _descriptor.Descriptor(
  name='DirectResponseAction',
  full_name='envoy.config.route.v4alpha.DirectResponseAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.config.route.v4alpha.DirectResponseAction.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007*\005\020\330\004(d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.config.route.v4alpha.DirectResponseAction.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.route.v3.DirectResponseAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12511,
  serialized_end=12665,
)


_DECORATOR = _descriptor.Descriptor(
  name='Decorator',
  full_name='envoy.config.route.v4alpha.Decorator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='envoy.config.route.v4alpha.Decorator.operation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagate', full_name='envoy.config.route.v4alpha.Decorator.propagate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.config.route.v3.Decorator',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12667,
  serialized_end=12793,
)


_TRACING = _descriptor.Descriptor(
  name='Tracing',
  full_name='envoy.config.route.v4alpha.Tracing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_sampling', full_name='envoy.config.route.v4alpha.Tracing.client_sampling', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_sampling', full_name='envoy.config.route.v4alpha.Tracing.random_sampling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall_sampling', full_name='envoy.config.route.v4alpha.Tracing.overall_sampling', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_tags', full_name='envoy.config.route.v4alpha.Tracing.custom_tags', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.config.route.v3.Tracing',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12796,
  serialized_end=13076,
)


_VIRTUALCLUSTER = _descriptor.Descriptor(
  name='VirtualCluster',
  full_name='envoy.config.route.v4alpha.VirtualCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.route.v4alpha.VirtualCluster.headers', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.VirtualCluster.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.config.route.v3.VirtualCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13079,
  serialized_end=13252,
)


_RATELIMIT_ACTION_SOURCECLUSTER = _descriptor.Descriptor(
  name='SourceCluster',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.SourceCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.route.v3.RateLimit.Action.SourceCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14164,
  serialized_end=14240,
)

_RATELIMIT_ACTION_DESTINATIONCLUSTER = _descriptor.Descriptor(
  name='DestinationCluster',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.DestinationCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.config.route.v3.RateLimit.Action.DestinationCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14242,
  serialized_end=14328,
)

_RATELIMIT_ACTION_REQUESTHEADERS = _descriptor.Descriptor(
  name='RequestHeaders',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.RequestHeaders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.config.route.v4alpha.RateLimit.Action.RequestHeaders.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.RequestHeaders.descriptor_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_if_absent', full_name='envoy.config.route.v4alpha.RateLimit.Action.RequestHeaders.skip_if_absent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.config.route.v3.RateLimit.Action.RequestHeaders',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14331,
  serialized_end=14502,
)

_RATELIMIT_ACTION_REMOTEADDRESS = _descriptor.Descriptor(
  name='RemoteAddress',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.RemoteAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.route.v3.RateLimit.Action.RemoteAddress',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14504,
  serialized_end=14580,
)

_RATELIMIT_ACTION_GENERICKEY = _descriptor.Descriptor(
  name='GenericKey',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.GenericKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_value', full_name='envoy.config.route.v4alpha.RateLimit.Action.GenericKey.descriptor_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.GenericKey.descriptor_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.route.v3.RateLimit.Action.GenericKey',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14583,
  serialized_end=14712,
)

_RATELIMIT_ACTION_HEADERVALUEMATCH = _descriptor.Descriptor(
  name='HeaderValueMatch',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_value', full_name='envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatch.descriptor_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expect_match', full_name='envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatch.expect_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatch.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0369\n7envoy.config.route.v3.RateLimit.Action.HeaderValueMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14715,
  serialized_end=14952,
)

_RATELIMIT_ACTION_DYNAMICMETADATA = _descriptor.Descriptor(
  name='DynamicMetaData',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.DynamicMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.DynamicMetaData.descriptor_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.DynamicMetaData.metadata_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.route.v4alpha.RateLimit.Action.DynamicMetaData.default_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.config.route.v3.RateLimit.Action.DynamicMetaData',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14955,
  serialized_end=15160,
)

_RATELIMIT_ACTION_METADATA = _descriptor.Descriptor(
  name='MetaData',
  full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData.descriptor_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData.metadata_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData.default_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='envoy.config.route.v4alpha.RateLimit.Action.MetaData.source', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RATELIMIT_ACTION_METADATA_SOURCE,
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.route.v3.RateLimit.Action.MetaData',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15163,
  serialized_end=15482,
)

_RATELIMIT_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='envoy.config.route.v4alpha.RateLimit.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cluster', full_name='envoy.config.route.v4alpha.RateLimit.Action.source_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_cluster', full_name='envoy.config.route.v4alpha.RateLimit.Action.destination_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.config.route.v4alpha.RateLimit.Action.request_headers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_address', full_name='envoy.config.route.v4alpha.RateLimit.Action.remote_address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generic_key', full_name='envoy.config.route.v4alpha.RateLimit.Action.generic_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_value_match', full_name='envoy.config.route.v4alpha.RateLimit.Action.header_value_match', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.route.v4alpha.RateLimit.Action.metadata', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension', full_name='envoy.config.route.v4alpha.RateLimit.Action.extension', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMIT_ACTION_SOURCECLUSTER, _RATELIMIT_ACTION_DESTINATIONCLUSTER, _RATELIMIT_ACTION_REQUESTHEADERS, _RATELIMIT_ACTION_REMOTEADDRESS, _RATELIMIT_ACTION_GENERICKEY, _RATELIMIT_ACTION_HEADERVALUEMATCH, _RATELIMIT_ACTION_DYNAMICMETADATA, _RATELIMIT_ACTION_METADATA, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.route.v3.RateLimit.Action',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action_specifier', full_name='envoy.config.route.v4alpha.RateLimit.Action.action_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=13480,
  serialized_end=15578,
)

_RATELIMIT_OVERRIDE_DYNAMICMETADATA = _descriptor.Descriptor(
  name='DynamicMetadata',
  full_name='envoy.config.route.v4alpha.RateLimit.Override.DynamicMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_key', full_name='envoy.config.route.v4alpha.RateLimit.Override.DynamicMetadata.metadata_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.route.v3.RateLimit.Override.DynamicMetadata',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15686,
  serialized_end=15837,
)

_RATELIMIT_OVERRIDE = _descriptor.Descriptor(
  name='Override',
  full_name='envoy.config.route.v4alpha.RateLimit.Override',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.config.route.v4alpha.RateLimit.Override.dynamic_metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMIT_OVERRIDE_DYNAMICMETADATA, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.route.v3.RateLimit.Override',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override_specifier', full_name='envoy.config.route.v4alpha.RateLimit.Override.override_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=15581,
  serialized_end=15913,
)

_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.config.route.v4alpha.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage', full_name='envoy.config.route.v4alpha.RateLimit.stage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_key', full_name='envoy.config.route.v4alpha.RateLimit.disable_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='envoy.config.route.v4alpha.RateLimit.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='envoy.config.route.v4alpha.RateLimit.limit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMIT_ACTION, _RATELIMIT_OVERRIDE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.config.route.v3.RateLimit',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13255,
  serialized_end=15953,
)


_HEADERMATCHER = _descriptor.Descriptor(
  name='HeaderMatcher',
  full_name='envoy.config.route.v4alpha.HeaderMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.HeaderMatcher.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exact_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.exact_match', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_regex_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.safe_regex_match', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.range_match', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.present_match', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.prefix_match', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suffix_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.suffix_match', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contains_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.contains_match', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invert_match', full_name='envoy.config.route.v4alpha.HeaderMatcher.invert_match', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.route.v3.HeaderMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='header_match_specifier', full_name='envoy.config.route.v4alpha.HeaderMatcher.header_match_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=15956,
  serialized_end=16392,
)


_QUERYPARAMETERMATCHER = _descriptor.Descriptor(
  name='QueryParameterMatcher',
  full_name='envoy.config.route.v4alpha.QueryParameterMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.QueryParameterMatcher.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001(\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_match', full_name='envoy.config.route.v4alpha.QueryParameterMatcher.string_match', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_match', full_name='envoy.config.route.v4alpha.QueryParameterMatcher.present_match', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.route.v3.QueryParameterMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query_parameter_match_specifier', full_name='envoy.config.route.v4alpha.QueryParameterMatcher.query_parameter_match_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16395,
  serialized_end=16659,
)


_INTERNALREDIRECTPOLICY = _descriptor.Descriptor(
  name='InternalRedirectPolicy',
  full_name='envoy.config.route.v4alpha.InternalRedirectPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_internal_redirects', full_name='envoy.config.route.v4alpha.InternalRedirectPolicy.max_internal_redirects', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_response_codes', full_name='envoy.config.route.v4alpha.InternalRedirectPolicy.redirect_response_codes', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\020\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicates', full_name='envoy.config.route.v4alpha.InternalRedirectPolicy.predicates', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_cross_scheme_redirect', full_name='envoy.config.route.v4alpha.InternalRedirectPolicy.allow_cross_scheme_redirect', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.route.v3.InternalRedirectPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16662,
  serialized_end=16950,
)


_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.config.route.v4alpha.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.route.v4alpha.FilterConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_optional', full_name='envoy.config.route.v4alpha.FilterConfig.is_optional', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.route.v3.FilterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16952,
  serialized_end=17068,
)

_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY.containing_type = _VIRTUALHOST
_VIRTUALHOST.fields_by_name['routes'].message_type = _ROUTE
_VIRTUALHOST.fields_by_name['require_tls'].enum_type = _VIRTUALHOST_TLSREQUIREMENTTYPE
_VIRTUALHOST.fields_by_name['virtual_clusters'].message_type = _VIRTUALCLUSTER
_VIRTUALHOST.fields_by_name['rate_limits'].message_type = _RATELIMIT
_VIRTUALHOST.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_VIRTUALHOST.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_VIRTUALHOST.fields_by_name['cors'].message_type = _CORSPOLICY
_VIRTUALHOST.fields_by_name['typed_per_filter_config'].message_type = _VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY
_VIRTUALHOST.fields_by_name['retry_policy'].message_type = _RETRYPOLICY
_VIRTUALHOST.fields_by_name['retry_policy_typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_VIRTUALHOST.fields_by_name['hedge_policy'].message_type = _HEDGEPOLICY
_VIRTUALHOST.fields_by_name['per_request_buffer_limit_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_VIRTUALHOST_TLSREQUIREMENTTYPE.containing_type = _VIRTUALHOST
_FILTERACTION.fields_by_name['action'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTE_TYPEDPERFILTERCONFIGENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTE_TYPEDPERFILTERCONFIGENTRY.containing_type = _ROUTE
_ROUTE.fields_by_name['match'].message_type = _ROUTEMATCH
_ROUTE.fields_by_name['route'].message_type = _ROUTEACTION
_ROUTE.fields_by_name['redirect'].message_type = _REDIRECTACTION
_ROUTE.fields_by_name['direct_response'].message_type = _DIRECTRESPONSEACTION
_ROUTE.fields_by_name['filter_action'].message_type = _FILTERACTION
_ROUTE.fields_by_name['metadata'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_ROUTE.fields_by_name['decorator'].message_type = _DECORATOR
_ROUTE.fields_by_name['typed_per_filter_config'].message_type = _ROUTE_TYPEDPERFILTERCONFIGENTRY
_ROUTE.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTE.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTE.fields_by_name['tracing'].message_type = _TRACING
_ROUTE.fields_by_name['per_request_buffer_limit_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_ROUTE.oneofs_by_name['action'].fields.append(
  _ROUTE.fields_by_name['route'])
_ROUTE.fields_by_name['route'].containing_oneof = _ROUTE.oneofs_by_name['action']
_ROUTE.oneofs_by_name['action'].fields.append(
  _ROUTE.fields_by_name['redirect'])
_ROUTE.fields_by_name['redirect'].containing_oneof = _ROUTE.oneofs_by_name['action']
_ROUTE.oneofs_by_name['action'].fields.append(
  _ROUTE.fields_by_name['direct_response'])
_ROUTE.fields_by_name['direct_response'].containing_oneof = _ROUTE.oneofs_by_name['action']
_ROUTE.oneofs_by_name['action'].fields.append(
  _ROUTE.fields_by_name['filter_action'])
_ROUTE.fields_by_name['filter_action'].containing_oneof = _ROUTE.oneofs_by_name['action']
_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY.containing_type = _WEIGHTEDCLUSTER_CLUSTERWEIGHT
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['typed_per_filter_config'].message_type = _WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.containing_type = _WEIGHTEDCLUSTER
_WEIGHTEDCLUSTER.fields_by_name['clusters'].message_type = _WEIGHTEDCLUSTER_CLUSTERWEIGHT
_WEIGHTEDCLUSTER.fields_by_name['total_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_ROUTEMATCH_GRPCROUTEMATCHOPTIONS.containing_type = _ROUTEMATCH
_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS.fields_by_name['presented'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS.fields_by_name['validated'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS.containing_type = _ROUTEMATCH
_ROUTEMATCH_CONNECTMATCHER.containing_type = _ROUTEMATCH
_ROUTEMATCH.fields_by_name['safe_regex'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHER
_ROUTEMATCH.fields_by_name['connect_matcher'].message_type = _ROUTEMATCH_CONNECTMATCHER
_ROUTEMATCH.fields_by_name['case_sensitive'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEMATCH.fields_by_name['runtime_fraction'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_ROUTEMATCH.fields_by_name['headers'].message_type = _HEADERMATCHER
_ROUTEMATCH.fields_by_name['query_parameters'].message_type = _QUERYPARAMETERMATCHER
_ROUTEMATCH.fields_by_name['grpc'].message_type = _ROUTEMATCH_GRPCROUTEMATCHOPTIONS
_ROUTEMATCH.fields_by_name['tls_context'].message_type = _ROUTEMATCH_TLSCONTEXTMATCHOPTIONS
_ROUTEMATCH.oneofs_by_name['path_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['prefix'])
_ROUTEMATCH.fields_by_name['prefix'].containing_oneof = _ROUTEMATCH.oneofs_by_name['path_specifier']
_ROUTEMATCH.oneofs_by_name['path_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['path'])
_ROUTEMATCH.fields_by_name['path'].containing_oneof = _ROUTEMATCH.oneofs_by_name['path_specifier']
_ROUTEMATCH.oneofs_by_name['path_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['safe_regex'])
_ROUTEMATCH.fields_by_name['safe_regex'].containing_oneof = _ROUTEMATCH.oneofs_by_name['path_specifier']
_ROUTEMATCH.oneofs_by_name['path_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['connect_matcher'])
_ROUTEMATCH.fields_by_name['connect_matcher'].containing_oneof = _ROUTEMATCH.oneofs_by_name['path_specifier']
_CORSPOLICY.fields_by_name['allow_origin_string_match'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_CORSPOLICY.fields_by_name['allow_credentials'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CORSPOLICY.fields_by_name['filter_enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CORSPOLICY.fields_by_name['shadow_enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CORSPOLICY.oneofs_by_name['enabled_specifier'].fields.append(
  _CORSPOLICY.fields_by_name['filter_enabled'])
_CORSPOLICY.fields_by_name['filter_enabled'].containing_oneof = _CORSPOLICY.oneofs_by_name['enabled_specifier']
_ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['runtime_fraction'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['trace_sampled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEACTION_REQUESTMIRRORPOLICY.containing_type = _ROUTEACTION
_ROUTEACTION_HASHPOLICY_HEADER.fields_by_name['regex_rewrite'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHANDSUBSTITUTE
_ROUTEACTION_HASHPOLICY_HEADER.containing_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION_HASHPOLICY_COOKIE.fields_by_name['ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION_HASHPOLICY_COOKIE.containing_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES.containing_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION_HASHPOLICY_QUERYPARAMETER.containing_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION_HASHPOLICY_FILTERSTATE.containing_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION_HASHPOLICY.fields_by_name['header'].message_type = _ROUTEACTION_HASHPOLICY_HEADER
_ROUTEACTION_HASHPOLICY.fields_by_name['cookie'].message_type = _ROUTEACTION_HASHPOLICY_COOKIE
_ROUTEACTION_HASHPOLICY.fields_by_name['connection_properties'].message_type = _ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES
_ROUTEACTION_HASHPOLICY.fields_by_name['query_parameter'].message_type = _ROUTEACTION_HASHPOLICY_QUERYPARAMETER
_ROUTEACTION_HASHPOLICY.fields_by_name['filter_state'].message_type = _ROUTEACTION_HASHPOLICY_FILTERSTATE
_ROUTEACTION_HASHPOLICY.containing_type = _ROUTEACTION
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _ROUTEACTION_HASHPOLICY.fields_by_name['header'])
_ROUTEACTION_HASHPOLICY.fields_by_name['header'].containing_oneof = _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _ROUTEACTION_HASHPOLICY.fields_by_name['cookie'])
_ROUTEACTION_HASHPOLICY.fields_by_name['cookie'].containing_oneof = _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _ROUTEACTION_HASHPOLICY.fields_by_name['connection_properties'])
_ROUTEACTION_HASHPOLICY.fields_by_name['connection_properties'].containing_oneof = _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _ROUTEACTION_HASHPOLICY.fields_by_name['query_parameter'])
_ROUTEACTION_HASHPOLICY.fields_by_name['query_parameter'].containing_oneof = _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _ROUTEACTION_HASHPOLICY.fields_by_name['filter_state'])
_ROUTEACTION_HASHPOLICY.fields_by_name['filter_state'].containing_oneof = _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']
_ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG.fields_by_name['proxy_protocol_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_proxy__protocol__pb2._PROXYPROTOCOLCONFIG
_ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG.containing_type = _ROUTEACTION_UPGRADECONFIG
_ROUTEACTION_UPGRADECONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEACTION_UPGRADECONFIG.fields_by_name['connect_config'].message_type = _ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG
_ROUTEACTION_UPGRADECONFIG.containing_type = _ROUTEACTION
_ROUTEACTION_MAXSTREAMDURATION.fields_by_name['max_stream_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION_MAXSTREAMDURATION.fields_by_name['grpc_timeout_header_max'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION_MAXSTREAMDURATION.fields_by_name['grpc_timeout_header_offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION_MAXSTREAMDURATION.containing_type = _ROUTEACTION
_ROUTEACTION.fields_by_name['weighted_clusters'].message_type = _WEIGHTEDCLUSTER
_ROUTEACTION.fields_by_name['cluster_not_found_response_code'].enum_type = _ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE
_ROUTEACTION.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_ROUTEACTION.fields_by_name['regex_rewrite'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHANDSUBSTITUTE
_ROUTEACTION.fields_by_name['auto_host_rewrite'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTEACTION.fields_by_name['host_rewrite_path_regex'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHANDSUBSTITUTE
_ROUTEACTION.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ROUTEACTION.fields_by_name['retry_policy'].message_type = _RETRYPOLICY
_ROUTEACTION.fields_by_name['retry_policy_typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTEACTION.fields_by_name['request_mirror_policies'].message_type = _ROUTEACTION_REQUESTMIRRORPOLICY
_ROUTEACTION.fields_by_name['priority'].enum_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._ROUTINGPRIORITY
_ROUTEACTION.fields_by_name['rate_limits'].message_type = _RATELIMIT
_ROUTEACTION.fields_by_name['hash_policy'].message_type = _ROUTEACTION_HASHPOLICY
_ROUTEACTION.fields_by_name['cors'].message_type = _CORSPOLICY
_ROUTEACTION.fields_by_name['upgrade_configs'].message_type = _ROUTEACTION_UPGRADECONFIG
_ROUTEACTION.fields_by_name['internal_redirect_policy'].message_type = _INTERNALREDIRECTPOLICY
_ROUTEACTION.fields_by_name['hedge_policy'].message_type = _HEDGEPOLICY
_ROUTEACTION.fields_by_name['max_stream_duration'].message_type = _ROUTEACTION_MAXSTREAMDURATION
_ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE.containing_type = _ROUTEACTION
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['cluster'])
_ROUTEACTION.fields_by_name['cluster'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['cluster_header'])
_ROUTEACTION.fields_by_name['cluster_header'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['weighted_clusters'])
_ROUTEACTION.fields_by_name['weighted_clusters'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['host_rewrite_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['host_rewrite_literal'])
_ROUTEACTION.fields_by_name['host_rewrite_literal'].containing_oneof = _ROUTEACTION.oneofs_by_name['host_rewrite_specifier']
_ROUTEACTION.oneofs_by_name['host_rewrite_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['auto_host_rewrite'])
_ROUTEACTION.fields_by_name['auto_host_rewrite'].containing_oneof = _ROUTEACTION.oneofs_by_name['host_rewrite_specifier']
_ROUTEACTION.oneofs_by_name['host_rewrite_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['host_rewrite_header'])
_ROUTEACTION.fields_by_name['host_rewrite_header'].containing_oneof = _ROUTEACTION.oneofs_by_name['host_rewrite_specifier']
_ROUTEACTION.oneofs_by_name['host_rewrite_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['host_rewrite_path_regex'])
_ROUTEACTION.fields_by_name['host_rewrite_path_regex'].containing_oneof = _ROUTEACTION.oneofs_by_name['host_rewrite_specifier']
_RETRYPOLICY_RETRYPRIORITY.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RETRYPOLICY_RETRYPRIORITY.containing_type = _RETRYPOLICY
_RETRYPOLICY_RETRYPRIORITY.oneofs_by_name['config_type'].fields.append(
  _RETRYPOLICY_RETRYPRIORITY.fields_by_name['typed_config'])
_RETRYPOLICY_RETRYPRIORITY.fields_by_name['typed_config'].containing_oneof = _RETRYPOLICY_RETRYPRIORITY.oneofs_by_name['config_type']
_RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RETRYPOLICY_RETRYHOSTPREDICATE.containing_type = _RETRYPOLICY
_RETRYPOLICY_RETRYHOSTPREDICATE.oneofs_by_name['config_type'].fields.append(
  _RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['typed_config'])
_RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['typed_config'].containing_oneof = _RETRYPOLICY_RETRYHOSTPREDICATE.oneofs_by_name['config_type']
_RETRYPOLICY_RETRYBACKOFF.fields_by_name['base_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYPOLICY_RETRYBACKOFF.fields_by_name['max_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYPOLICY_RETRYBACKOFF.containing_type = _RETRYPOLICY
_RETRYPOLICY_RESETHEADER.fields_by_name['format'].enum_type = _RETRYPOLICY_RESETHEADERFORMAT
_RETRYPOLICY_RESETHEADER.containing_type = _RETRYPOLICY
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF.fields_by_name['reset_headers'].message_type = _RETRYPOLICY_RESETHEADER
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF.fields_by_name['max_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF.containing_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name['max_retries'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_RETRYPOLICY.fields_by_name['per_try_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYPOLICY.fields_by_name['retry_priority'].message_type = _RETRYPOLICY_RETRYPRIORITY
_RETRYPOLICY.fields_by_name['retry_host_predicate'].message_type = _RETRYPOLICY_RETRYHOSTPREDICATE
_RETRYPOLICY.fields_by_name['retry_back_off'].message_type = _RETRYPOLICY_RETRYBACKOFF
_RETRYPOLICY.fields_by_name['rate_limited_retry_back_off'].message_type = _RETRYPOLICY_RATELIMITEDRETRYBACKOFF
_RETRYPOLICY.fields_by_name['retriable_headers'].message_type = _HEADERMATCHER
_RETRYPOLICY.fields_by_name['retriable_request_headers'].message_type = _HEADERMATCHER
_RETRYPOLICY_RESETHEADERFORMAT.containing_type = _RETRYPOLICY
_HEDGEPOLICY.fields_by_name['initial_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEDGEPOLICY.fields_by_name['additional_request_chance'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_REDIRECTACTION.fields_by_name['regex_rewrite'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHANDSUBSTITUTE
_REDIRECTACTION.fields_by_name['response_code'].enum_type = _REDIRECTACTION_REDIRECTRESPONSECODE
_REDIRECTACTION_REDIRECTRESPONSECODE.containing_type = _REDIRECTACTION
_REDIRECTACTION.oneofs_by_name['scheme_rewrite_specifier'].fields.append(
  _REDIRECTACTION.fields_by_name['https_redirect'])
_REDIRECTACTION.fields_by_name['https_redirect'].containing_oneof = _REDIRECTACTION.oneofs_by_name['scheme_rewrite_specifier']
_REDIRECTACTION.oneofs_by_name['scheme_rewrite_specifier'].fields.append(
  _REDIRECTACTION.fields_by_name['scheme_redirect'])
_REDIRECTACTION.fields_by_name['scheme_redirect'].containing_oneof = _REDIRECTACTION.oneofs_by_name['scheme_rewrite_specifier']
_REDIRECTACTION.oneofs_by_name['path_rewrite_specifier'].fields.append(
  _REDIRECTACTION.fields_by_name['path_redirect'])
_REDIRECTACTION.fields_by_name['path_redirect'].containing_oneof = _REDIRECTACTION.oneofs_by_name['path_rewrite_specifier']
_REDIRECTACTION.oneofs_by_name['path_rewrite_specifier'].fields.append(
  _REDIRECTACTION.fields_by_name['prefix_rewrite'])
_REDIRECTACTION.fields_by_name['prefix_rewrite'].containing_oneof = _REDIRECTACTION.oneofs_by_name['path_rewrite_specifier']
_REDIRECTACTION.oneofs_by_name['path_rewrite_specifier'].fields.append(
  _REDIRECTACTION.fields_by_name['regex_rewrite'])
_REDIRECTACTION.fields_by_name['regex_rewrite'].containing_oneof = _REDIRECTACTION.oneofs_by_name['path_rewrite_specifier']
_DIRECTRESPONSEACTION.fields_by_name['body'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_DECORATOR.fields_by_name['propagate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRACING.fields_by_name['client_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_TRACING.fields_by_name['random_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_TRACING.fields_by_name['overall_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_TRACING.fields_by_name['custom_tags'].message_type = envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2._CUSTOMTAG
_VIRTUALCLUSTER.fields_by_name['headers'].message_type = _HEADERMATCHER
_RATELIMIT_ACTION_SOURCECLUSTER.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_DESTINATIONCLUSTER.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_REQUESTHEADERS.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_REMOTEADDRESS.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_GENERICKEY.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['expect_match'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['headers'].message_type = _HEADERMATCHER
_RATELIMIT_ACTION_HEADERVALUEMATCH.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_DYNAMICMETADATA.fields_by_name['metadata_key'].message_type = envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2._METADATAKEY
_RATELIMIT_ACTION_DYNAMICMETADATA.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_METADATA.fields_by_name['metadata_key'].message_type = envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2._METADATAKEY
_RATELIMIT_ACTION_METADATA.fields_by_name['source'].enum_type = _RATELIMIT_ACTION_METADATA_SOURCE
_RATELIMIT_ACTION_METADATA.containing_type = _RATELIMIT_ACTION
_RATELIMIT_ACTION_METADATA_SOURCE.containing_type = _RATELIMIT_ACTION_METADATA
_RATELIMIT_ACTION.fields_by_name['source_cluster'].message_type = _RATELIMIT_ACTION_SOURCECLUSTER
_RATELIMIT_ACTION.fields_by_name['destination_cluster'].message_type = _RATELIMIT_ACTION_DESTINATIONCLUSTER
_RATELIMIT_ACTION.fields_by_name['request_headers'].message_type = _RATELIMIT_ACTION_REQUESTHEADERS
_RATELIMIT_ACTION.fields_by_name['remote_address'].message_type = _RATELIMIT_ACTION_REMOTEADDRESS
_RATELIMIT_ACTION.fields_by_name['generic_key'].message_type = _RATELIMIT_ACTION_GENERICKEY
_RATELIMIT_ACTION.fields_by_name['header_value_match'].message_type = _RATELIMIT_ACTION_HEADERVALUEMATCH
_RATELIMIT_ACTION.fields_by_name['metadata'].message_type = _RATELIMIT_ACTION_METADATA
_RATELIMIT_ACTION.fields_by_name['extension'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_RATELIMIT_ACTION.containing_type = _RATELIMIT
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['source_cluster'])
_RATELIMIT_ACTION.fields_by_name['source_cluster'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['destination_cluster'])
_RATELIMIT_ACTION.fields_by_name['destination_cluster'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['request_headers'])
_RATELIMIT_ACTION.fields_by_name['request_headers'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['remote_address'])
_RATELIMIT_ACTION.fields_by_name['remote_address'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['generic_key'])
_RATELIMIT_ACTION.fields_by_name['generic_key'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['header_value_match'])
_RATELIMIT_ACTION.fields_by_name['header_value_match'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['metadata'])
_RATELIMIT_ACTION.fields_by_name['metadata'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_ACTION.oneofs_by_name['action_specifier'].fields.append(
  _RATELIMIT_ACTION.fields_by_name['extension'])
_RATELIMIT_ACTION.fields_by_name['extension'].containing_oneof = _RATELIMIT_ACTION.oneofs_by_name['action_specifier']
_RATELIMIT_OVERRIDE_DYNAMICMETADATA.fields_by_name['metadata_key'].message_type = envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2._METADATAKEY
_RATELIMIT_OVERRIDE_DYNAMICMETADATA.containing_type = _RATELIMIT_OVERRIDE
_RATELIMIT_OVERRIDE.fields_by_name['dynamic_metadata'].message_type = _RATELIMIT_OVERRIDE_DYNAMICMETADATA
_RATELIMIT_OVERRIDE.containing_type = _RATELIMIT
_RATELIMIT_OVERRIDE.oneofs_by_name['override_specifier'].fields.append(
  _RATELIMIT_OVERRIDE.fields_by_name['dynamic_metadata'])
_RATELIMIT_OVERRIDE.fields_by_name['dynamic_metadata'].containing_oneof = _RATELIMIT_OVERRIDE.oneofs_by_name['override_specifier']
_RATELIMIT.fields_by_name['stage'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_RATELIMIT.fields_by_name['actions'].message_type = _RATELIMIT_ACTION
_RATELIMIT.fields_by_name['limit'].message_type = _RATELIMIT_OVERRIDE
_HEADERMATCHER.fields_by_name['safe_regex_match'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHER
_HEADERMATCHER.fields_by_name['range_match'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT64RANGE
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['exact_match'])
_HEADERMATCHER.fields_by_name['exact_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['safe_regex_match'])
_HEADERMATCHER.fields_by_name['safe_regex_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['range_match'])
_HEADERMATCHER.fields_by_name['range_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['present_match'])
_HEADERMATCHER.fields_by_name['present_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['prefix_match'])
_HEADERMATCHER.fields_by_name['prefix_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['suffix_match'])
_HEADERMATCHER.fields_by_name['suffix_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_HEADERMATCHER.oneofs_by_name['header_match_specifier'].fields.append(
  _HEADERMATCHER.fields_by_name['contains_match'])
_HEADERMATCHER.fields_by_name['contains_match'].containing_oneof = _HEADERMATCHER.oneofs_by_name['header_match_specifier']
_QUERYPARAMETERMATCHER.fields_by_name['string_match'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_QUERYPARAMETERMATCHER.oneofs_by_name['query_parameter_match_specifier'].fields.append(
  _QUERYPARAMETERMATCHER.fields_by_name['string_match'])
_QUERYPARAMETERMATCHER.fields_by_name['string_match'].containing_oneof = _QUERYPARAMETERMATCHER.oneofs_by_name['query_parameter_match_specifier']
_QUERYPARAMETERMATCHER.oneofs_by_name['query_parameter_match_specifier'].fields.append(
  _QUERYPARAMETERMATCHER.fields_by_name['present_match'])
_QUERYPARAMETERMATCHER.fields_by_name['present_match'].containing_oneof = _QUERYPARAMETERMATCHER.oneofs_by_name['query_parameter_match_specifier']
_INTERNALREDIRECTPOLICY.fields_by_name['max_internal_redirects'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_INTERNALREDIRECTPOLICY.fields_by_name['predicates'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_FILTERCONFIG.fields_by_name['config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['VirtualHost'] = _VIRTUALHOST
DESCRIPTOR.message_types_by_name['FilterAction'] = _FILTERACTION
DESCRIPTOR.message_types_by_name['Route'] = _ROUTE
DESCRIPTOR.message_types_by_name['WeightedCluster'] = _WEIGHTEDCLUSTER
DESCRIPTOR.message_types_by_name['RouteMatch'] = _ROUTEMATCH
DESCRIPTOR.message_types_by_name['CorsPolicy'] = _CORSPOLICY
DESCRIPTOR.message_types_by_name['RouteAction'] = _ROUTEACTION
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
DESCRIPTOR.message_types_by_name['HedgePolicy'] = _HEDGEPOLICY
DESCRIPTOR.message_types_by_name['RedirectAction'] = _REDIRECTACTION
DESCRIPTOR.message_types_by_name['DirectResponseAction'] = _DIRECTRESPONSEACTION
DESCRIPTOR.message_types_by_name['Decorator'] = _DECORATOR
DESCRIPTOR.message_types_by_name['Tracing'] = _TRACING
DESCRIPTOR.message_types_by_name['VirtualCluster'] = _VIRTUALCLUSTER
DESCRIPTOR.message_types_by_name['RateLimit'] = _RATELIMIT
DESCRIPTOR.message_types_by_name['HeaderMatcher'] = _HEADERMATCHER
DESCRIPTOR.message_types_by_name['QueryParameterMatcher'] = _QUERYPARAMETERMATCHER
DESCRIPTOR.message_types_by_name['InternalRedirectPolicy'] = _INTERNALREDIRECTPOLICY
DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VirtualHost = _reflection.GeneratedProtocolMessageType('VirtualHost', (_message.Message,), {

  'TypedPerFilterConfigEntry' : _reflection.GeneratedProtocolMessageType('TypedPerFilterConfigEntry', (_message.Message,), {
    'DESCRIPTOR' : _VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.VirtualHost.TypedPerFilterConfigEntry)
    })
  ,
  'DESCRIPTOR' : _VIRTUALHOST,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.VirtualHost)
  })
_sym_db.RegisterMessage(VirtualHost)
_sym_db.RegisterMessage(VirtualHost.TypedPerFilterConfigEntry)

FilterAction = _reflection.GeneratedProtocolMessageType('FilterAction', (_message.Message,), {
  'DESCRIPTOR' : _FILTERACTION,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.FilterAction)
  })
_sym_db.RegisterMessage(FilterAction)

Route = _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {

  'TypedPerFilterConfigEntry' : _reflection.GeneratedProtocolMessageType('TypedPerFilterConfigEntry', (_message.Message,), {
    'DESCRIPTOR' : _ROUTE_TYPEDPERFILTERCONFIGENTRY,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Route.TypedPerFilterConfigEntry)
    })
  ,
  'DESCRIPTOR' : _ROUTE,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Route)
  })
_sym_db.RegisterMessage(Route)
_sym_db.RegisterMessage(Route.TypedPerFilterConfigEntry)

WeightedCluster = _reflection.GeneratedProtocolMessageType('WeightedCluster', (_message.Message,), {

  'ClusterWeight' : _reflection.GeneratedProtocolMessageType('ClusterWeight', (_message.Message,), {

    'TypedPerFilterConfigEntry' : _reflection.GeneratedProtocolMessageType('TypedPerFilterConfigEntry', (_message.Message,), {
      'DESCRIPTOR' : _WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry)
      })
    ,
    'DESCRIPTOR' : _WEIGHTEDCLUSTER_CLUSTERWEIGHT,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.WeightedCluster.ClusterWeight)
    })
  ,
  'DESCRIPTOR' : _WEIGHTEDCLUSTER,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.WeightedCluster)
  })
_sym_db.RegisterMessage(WeightedCluster)
_sym_db.RegisterMessage(WeightedCluster.ClusterWeight)
_sym_db.RegisterMessage(WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry)

RouteMatch = _reflection.GeneratedProtocolMessageType('RouteMatch', (_message.Message,), {

  'GrpcRouteMatchOptions' : _reflection.GeneratedProtocolMessageType('GrpcRouteMatchOptions', (_message.Message,), {
    'DESCRIPTOR' : _ROUTEMATCH_GRPCROUTEMATCHOPTIONS,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteMatch.GrpcRouteMatchOptions)
    })
  ,

  'TlsContextMatchOptions' : _reflection.GeneratedProtocolMessageType('TlsContextMatchOptions', (_message.Message,), {
    'DESCRIPTOR' : _ROUTEMATCH_TLSCONTEXTMATCHOPTIONS,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteMatch.TlsContextMatchOptions)
    })
  ,

  'ConnectMatcher' : _reflection.GeneratedProtocolMessageType('ConnectMatcher', (_message.Message,), {
    'DESCRIPTOR' : _ROUTEMATCH_CONNECTMATCHER,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteMatch.ConnectMatcher)
    })
  ,
  'DESCRIPTOR' : _ROUTEMATCH,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteMatch)
  })
_sym_db.RegisterMessage(RouteMatch)
_sym_db.RegisterMessage(RouteMatch.GrpcRouteMatchOptions)
_sym_db.RegisterMessage(RouteMatch.TlsContextMatchOptions)
_sym_db.RegisterMessage(RouteMatch.ConnectMatcher)

CorsPolicy = _reflection.GeneratedProtocolMessageType('CorsPolicy', (_message.Message,), {
  'DESCRIPTOR' : _CORSPOLICY,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.CorsPolicy)
  })
_sym_db.RegisterMessage(CorsPolicy)

RouteAction = _reflection.GeneratedProtocolMessageType('RouteAction', (_message.Message,), {

  'RequestMirrorPolicy' : _reflection.GeneratedProtocolMessageType('RequestMirrorPolicy', (_message.Message,), {
    'DESCRIPTOR' : _ROUTEACTION_REQUESTMIRRORPOLICY,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.RequestMirrorPolicy)
    })
  ,

  'HashPolicy' : _reflection.GeneratedProtocolMessageType('HashPolicy', (_message.Message,), {

    'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY_HEADER,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy.Header)
      })
    ,

    'Cookie' : _reflection.GeneratedProtocolMessageType('Cookie', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY_COOKIE,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy.Cookie)
      })
    ,

    'ConnectionProperties' : _reflection.GeneratedProtocolMessageType('ConnectionProperties', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy.ConnectionProperties)
      })
    ,

    'QueryParameter' : _reflection.GeneratedProtocolMessageType('QueryParameter', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY_QUERYPARAMETER,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy.QueryParameter)
      })
    ,

    'FilterState' : _reflection.GeneratedProtocolMessageType('FilterState', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY_FILTERSTATE,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy.FilterState)
      })
    ,
    'DESCRIPTOR' : _ROUTEACTION_HASHPOLICY,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.HashPolicy)
    })
  ,

  'UpgradeConfig' : _reflection.GeneratedProtocolMessageType('UpgradeConfig', (_message.Message,), {

    'ConnectConfig' : _reflection.GeneratedProtocolMessageType('ConnectConfig', (_message.Message,), {
      'DESCRIPTOR' : _ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.UpgradeConfig.ConnectConfig)
      })
    ,
    'DESCRIPTOR' : _ROUTEACTION_UPGRADECONFIG,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.UpgradeConfig)
    })
  ,

  'MaxStreamDuration' : _reflection.GeneratedProtocolMessageType('MaxStreamDuration', (_message.Message,), {
    'DESCRIPTOR' : _ROUTEACTION_MAXSTREAMDURATION,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction.MaxStreamDuration)
    })
  ,
  'DESCRIPTOR' : _ROUTEACTION,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteAction)
  })
_sym_db.RegisterMessage(RouteAction)
_sym_db.RegisterMessage(RouteAction.RequestMirrorPolicy)
_sym_db.RegisterMessage(RouteAction.HashPolicy)
_sym_db.RegisterMessage(RouteAction.HashPolicy.Header)
_sym_db.RegisterMessage(RouteAction.HashPolicy.Cookie)
_sym_db.RegisterMessage(RouteAction.HashPolicy.ConnectionProperties)
_sym_db.RegisterMessage(RouteAction.HashPolicy.QueryParameter)
_sym_db.RegisterMessage(RouteAction.HashPolicy.FilterState)
_sym_db.RegisterMessage(RouteAction.UpgradeConfig)
_sym_db.RegisterMessage(RouteAction.UpgradeConfig.ConnectConfig)
_sym_db.RegisterMessage(RouteAction.MaxStreamDuration)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {

  'RetryPriority' : _reflection.GeneratedProtocolMessageType('RetryPriority', (_message.Message,), {
    'DESCRIPTOR' : _RETRYPOLICY_RETRYPRIORITY,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy.RetryPriority)
    })
  ,

  'RetryHostPredicate' : _reflection.GeneratedProtocolMessageType('RetryHostPredicate', (_message.Message,), {
    'DESCRIPTOR' : _RETRYPOLICY_RETRYHOSTPREDICATE,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy.RetryHostPredicate)
    })
  ,

  'RetryBackOff' : _reflection.GeneratedProtocolMessageType('RetryBackOff', (_message.Message,), {
    'DESCRIPTOR' : _RETRYPOLICY_RETRYBACKOFF,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy.RetryBackOff)
    })
  ,

  'ResetHeader' : _reflection.GeneratedProtocolMessageType('ResetHeader', (_message.Message,), {
    'DESCRIPTOR' : _RETRYPOLICY_RESETHEADER,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy.ResetHeader)
    })
  ,

  'RateLimitedRetryBackOff' : _reflection.GeneratedProtocolMessageType('RateLimitedRetryBackOff', (_message.Message,), {
    'DESCRIPTOR' : _RETRYPOLICY_RATELIMITEDRETRYBACKOFF,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy.RateLimitedRetryBackOff)
    })
  ,
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)
_sym_db.RegisterMessage(RetryPolicy.RetryPriority)
_sym_db.RegisterMessage(RetryPolicy.RetryHostPredicate)
_sym_db.RegisterMessage(RetryPolicy.RetryBackOff)
_sym_db.RegisterMessage(RetryPolicy.ResetHeader)
_sym_db.RegisterMessage(RetryPolicy.RateLimitedRetryBackOff)

HedgePolicy = _reflection.GeneratedProtocolMessageType('HedgePolicy', (_message.Message,), {
  'DESCRIPTOR' : _HEDGEPOLICY,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.HedgePolicy)
  })
_sym_db.RegisterMessage(HedgePolicy)

RedirectAction = _reflection.GeneratedProtocolMessageType('RedirectAction', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTACTION,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RedirectAction)
  })
_sym_db.RegisterMessage(RedirectAction)

DirectResponseAction = _reflection.GeneratedProtocolMessageType('DirectResponseAction', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTRESPONSEACTION,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.DirectResponseAction)
  })
_sym_db.RegisterMessage(DirectResponseAction)

Decorator = _reflection.GeneratedProtocolMessageType('Decorator', (_message.Message,), {
  'DESCRIPTOR' : _DECORATOR,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Decorator)
  })
_sym_db.RegisterMessage(Decorator)

Tracing = _reflection.GeneratedProtocolMessageType('Tracing', (_message.Message,), {
  'DESCRIPTOR' : _TRACING,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Tracing)
  })
_sym_db.RegisterMessage(Tracing)

VirtualCluster = _reflection.GeneratedProtocolMessageType('VirtualCluster', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALCLUSTER,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.VirtualCluster)
  })
_sym_db.RegisterMessage(VirtualCluster)

RateLimit = _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {

  'Action' : _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {

    'SourceCluster' : _reflection.GeneratedProtocolMessageType('SourceCluster', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_SOURCECLUSTER,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.SourceCluster)
      })
    ,

    'DestinationCluster' : _reflection.GeneratedProtocolMessageType('DestinationCluster', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_DESTINATIONCLUSTER,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.DestinationCluster)
      })
    ,

    'RequestHeaders' : _reflection.GeneratedProtocolMessageType('RequestHeaders', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_REQUESTHEADERS,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.RequestHeaders)
      })
    ,

    'RemoteAddress' : _reflection.GeneratedProtocolMessageType('RemoteAddress', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_REMOTEADDRESS,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.RemoteAddress)
      })
    ,

    'GenericKey' : _reflection.GeneratedProtocolMessageType('GenericKey', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_GENERICKEY,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.GenericKey)
      })
    ,

    'HeaderValueMatch' : _reflection.GeneratedProtocolMessageType('HeaderValueMatch', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_HEADERVALUEMATCH,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.HeaderValueMatch)
      })
    ,

    'DynamicMetaData' : _reflection.GeneratedProtocolMessageType('DynamicMetaData', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_DYNAMICMETADATA,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.DynamicMetaData)
      })
    ,

    'MetaData' : _reflection.GeneratedProtocolMessageType('MetaData', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_ACTION_METADATA,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action.MetaData)
      })
    ,
    'DESCRIPTOR' : _RATELIMIT_ACTION,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Action)
    })
  ,

  'Override' : _reflection.GeneratedProtocolMessageType('Override', (_message.Message,), {

    'DynamicMetadata' : _reflection.GeneratedProtocolMessageType('DynamicMetadata', (_message.Message,), {
      'DESCRIPTOR' : _RATELIMIT_OVERRIDE_DYNAMICMETADATA,
      '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Override.DynamicMetadata)
      })
    ,
    'DESCRIPTOR' : _RATELIMIT_OVERRIDE,
    '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit.Override)
    })
  ,
  'DESCRIPTOR' : _RATELIMIT,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RateLimit)
  })
_sym_db.RegisterMessage(RateLimit)
_sym_db.RegisterMessage(RateLimit.Action)
_sym_db.RegisterMessage(RateLimit.Action.SourceCluster)
_sym_db.RegisterMessage(RateLimit.Action.DestinationCluster)
_sym_db.RegisterMessage(RateLimit.Action.RequestHeaders)
_sym_db.RegisterMessage(RateLimit.Action.RemoteAddress)
_sym_db.RegisterMessage(RateLimit.Action.GenericKey)
_sym_db.RegisterMessage(RateLimit.Action.HeaderValueMatch)
_sym_db.RegisterMessage(RateLimit.Action.DynamicMetaData)
_sym_db.RegisterMessage(RateLimit.Action.MetaData)
_sym_db.RegisterMessage(RateLimit.Override)
_sym_db.RegisterMessage(RateLimit.Override.DynamicMetadata)

HeaderMatcher = _reflection.GeneratedProtocolMessageType('HeaderMatcher', (_message.Message,), {
  'DESCRIPTOR' : _HEADERMATCHER,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.HeaderMatcher)
  })
_sym_db.RegisterMessage(HeaderMatcher)

QueryParameterMatcher = _reflection.GeneratedProtocolMessageType('QueryParameterMatcher', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMETERMATCHER,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.QueryParameterMatcher)
  })
_sym_db.RegisterMessage(QueryParameterMatcher)

InternalRedirectPolicy = _reflection.GeneratedProtocolMessageType('InternalRedirectPolicy', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALREDIRECTPOLICY,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.InternalRedirectPolicy)
  })
_sym_db.RegisterMessage(InternalRedirectPolicy)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.config.route.v4alpha.route_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)


DESCRIPTOR._options = None
_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY._options = None
_VIRTUALHOST.fields_by_name['name']._options = None
_VIRTUALHOST.fields_by_name['domains']._options = None
_VIRTUALHOST.fields_by_name['require_tls']._options = None
_VIRTUALHOST.fields_by_name['request_headers_to_add']._options = None
_VIRTUALHOST.fields_by_name['request_headers_to_remove']._options = None
_VIRTUALHOST.fields_by_name['response_headers_to_add']._options = None
_VIRTUALHOST.fields_by_name['response_headers_to_remove']._options = None
_VIRTUALHOST._options = None
_FILTERACTION._options = None
_ROUTE_TYPEDPERFILTERCONFIGENTRY._options = None
_ROUTE.oneofs_by_name['action']._options = None
_ROUTE.fields_by_name['match']._options = None
_ROUTE.fields_by_name['request_headers_to_add']._options = None
_ROUTE.fields_by_name['request_headers_to_remove']._options = None
_ROUTE.fields_by_name['response_headers_to_add']._options = None
_ROUTE.fields_by_name['response_headers_to_remove']._options = None
_ROUTE._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['request_headers_to_add']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['request_headers_to_remove']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['response_headers_to_add']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['response_headers_to_remove']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT._options = None
_WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
_WEIGHTEDCLUSTER.fields_by_name['total_weight']._options = None
_WEIGHTEDCLUSTER._options = None
_ROUTEMATCH_GRPCROUTEMATCHOPTIONS._options = None
_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS._options = None
_ROUTEMATCH_CONNECTMATCHER._options = None
_ROUTEMATCH.oneofs_by_name['path_specifier']._options = None
_ROUTEMATCH.fields_by_name['safe_regex']._options = None
_ROUTEMATCH._options = None
_CORSPOLICY._options = None
_ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
_ROUTEACTION_REQUESTMIRRORPOLICY._options = None
_ROUTEACTION_HASHPOLICY_HEADER.fields_by_name['header_name']._options = None
_ROUTEACTION_HASHPOLICY_HEADER._options = None
_ROUTEACTION_HASHPOLICY_COOKIE.fields_by_name['name']._options = None
_ROUTEACTION_HASHPOLICY_COOKIE._options = None
_ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES._options = None
_ROUTEACTION_HASHPOLICY_QUERYPARAMETER.fields_by_name['name']._options = None
_ROUTEACTION_HASHPOLICY_QUERYPARAMETER._options = None
_ROUTEACTION_HASHPOLICY_FILTERSTATE.fields_by_name['key']._options = None
_ROUTEACTION_HASHPOLICY_FILTERSTATE._options = None
_ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
_ROUTEACTION_HASHPOLICY._options = None
_ROUTEACTION_UPGRADECONFIG_CONNECTCONFIG._options = None
_ROUTEACTION_UPGRADECONFIG.fields_by_name['upgrade_type']._options = None
_ROUTEACTION_UPGRADECONFIG._options = None
_ROUTEACTION_MAXSTREAMDURATION._options = None
_ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
_ROUTEACTION.fields_by_name['cluster']._options = None
_ROUTEACTION.fields_by_name['cluster_header']._options = None
_ROUTEACTION.fields_by_name['cluster_not_found_response_code']._options = None
_ROUTEACTION.fields_by_name['prefix_rewrite']._options = None
_ROUTEACTION.fields_by_name['host_rewrite_literal']._options = None
_ROUTEACTION.fields_by_name['host_rewrite_header']._options = None
_ROUTEACTION.fields_by_name['priority']._options = None
_ROUTEACTION._options = None
_RETRYPOLICY_RETRYPRIORITY.fields_by_name['name']._options = None
_RETRYPOLICY_RETRYPRIORITY._options = None
_RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['name']._options = None
_RETRYPOLICY_RETRYHOSTPREDICATE._options = None
_RETRYPOLICY_RETRYBACKOFF.fields_by_name['base_interval']._options = None
_RETRYPOLICY_RETRYBACKOFF.fields_by_name['max_interval']._options = None
_RETRYPOLICY_RETRYBACKOFF._options = None
_RETRYPOLICY_RESETHEADER.fields_by_name['name']._options = None
_RETRYPOLICY_RESETHEADER.fields_by_name['format']._options = None
_RETRYPOLICY_RESETHEADER._options = None
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF.fields_by_name['reset_headers']._options = None
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF.fields_by_name['max_interval']._options = None
_RETRYPOLICY_RATELIMITEDRETRYBACKOFF._options = None
_RETRYPOLICY._options = None
_HEDGEPOLICY.fields_by_name['initial_requests']._options = None
_HEDGEPOLICY._options = None
_REDIRECTACTION.fields_by_name['host_redirect']._options = None
_REDIRECTACTION.fields_by_name['path_redirect']._options = None
_REDIRECTACTION.fields_by_name['prefix_rewrite']._options = None
_REDIRECTACTION.fields_by_name['response_code']._options = None
_REDIRECTACTION._options = None
_DIRECTRESPONSEACTION.fields_by_name['status']._options = None
_DIRECTRESPONSEACTION._options = None
_DECORATOR.fields_by_name['operation']._options = None
_DECORATOR._options = None
_TRACING._options = None
_VIRTUALCLUSTER.fields_by_name['name']._options = None
_VIRTUALCLUSTER._options = None
_RATELIMIT_ACTION_SOURCECLUSTER._options = None
_RATELIMIT_ACTION_DESTINATIONCLUSTER._options = None
_RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['header_name']._options = None
_RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['descriptor_key']._options = None
_RATELIMIT_ACTION_REQUESTHEADERS._options = None
_RATELIMIT_ACTION_REMOTEADDRESS._options = None
_RATELIMIT_ACTION_GENERICKEY.fields_by_name['descriptor_value']._options = None
_RATELIMIT_ACTION_GENERICKEY._options = None
_RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['descriptor_value']._options = None
_RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['headers']._options = None
_RATELIMIT_ACTION_HEADERVALUEMATCH._options = None
_RATELIMIT_ACTION_DYNAMICMETADATA.fields_by_name['descriptor_key']._options = None
_RATELIMIT_ACTION_DYNAMICMETADATA.fields_by_name['metadata_key']._options = None
_RATELIMIT_ACTION_DYNAMICMETADATA._options = None
_RATELIMIT_ACTION_METADATA.fields_by_name['descriptor_key']._options = None
_RATELIMIT_ACTION_METADATA.fields_by_name['metadata_key']._options = None
_RATELIMIT_ACTION_METADATA.fields_by_name['source']._options = None
_RATELIMIT_ACTION_METADATA._options = None
_RATELIMIT_ACTION.oneofs_by_name['action_specifier']._options = None
_RATELIMIT_ACTION._options = None
_RATELIMIT_OVERRIDE_DYNAMICMETADATA.fields_by_name['metadata_key']._options = None
_RATELIMIT_OVERRIDE_DYNAMICMETADATA._options = None
_RATELIMIT_OVERRIDE.oneofs_by_name['override_specifier']._options = None
_RATELIMIT_OVERRIDE._options = None
_RATELIMIT.fields_by_name['stage']._options = None
_RATELIMIT.fields_by_name['actions']._options = None
_RATELIMIT._options = None
_HEADERMATCHER.fields_by_name['name']._options = None
_HEADERMATCHER.fields_by_name['prefix_match']._options = None
_HEADERMATCHER.fields_by_name['suffix_match']._options = None
_HEADERMATCHER.fields_by_name['contains_match']._options = None
_HEADERMATCHER._options = None
_QUERYPARAMETERMATCHER.fields_by_name['name']._options = None
_QUERYPARAMETERMATCHER.fields_by_name['string_match']._options = None
_QUERYPARAMETERMATCHER._options = None
_INTERNALREDIRECTPOLICY.fields_by_name['redirect_response_codes']._options = None
_INTERNALREDIRECTPOLICY._options = None
_FILTERCONFIG._options = None
# @@protoc_insertion_point(module_scope)
